;;;---------------------------------------------------------------;;;
;;;                                                               ;;;
;;;                  HIP ROOF - 2D RIDGE EDGES                    ;;;
;;;                  ALTERNATE SOLUTION FINDER                    ;;;
;;;                                                               ;;;
;;;  Author : Marko Ribar, d.i.a. (architect)                     ;;;
;;;  Autolisp routine for AutoCAD or BricsCAD                     ;;;
;;;  Copyright (C) 2021.                                          ;;;
;;;  Tested and programmed on Windows 10 OS                       ;;;
;;;  Bugs or failures may appear and aren't authors responsibility;;;
;;;  LSP file is free to be used for improvements...              ;;;
;;;  All relevant suggestions are welcomed...                     ;;;
;;;                                                               ;;;
;;;---------------------------------------------------------------;;;

(defun c:roof2d-new-new-solutions ( / *error* uniquelillst unique unit mid clockwise-p inside-p distp2t offsett2p removesingles removedoubles correctplanedist collinear-p unioncollinearplaneprints car-sort processtxtipl chksolution test chklili findlinesbetweentl processipl processipll processplaa processplaa-x process processipll-n processplaa-n process-n postprocess cmde s ti lw lwi lwx pl tl utl pla plao n plaa x y lil ipl ipldl ll flag errli errlis liloo lilo loop ip pla1 ipllsort maxlen iplls iplls1 ipld ipldd mode closed op x1 x2 xx xxx xxx1 xxx2 xxxx xxxx1 xxxx2 ff plaal chk lixl plaox lilx fflag plaoxl lill lilxplaoxl merrlis lils lillst lillsto dx k fff )

  (vl-load-com)

  (defun *error* ( m )
    (if cmde
      (setvar 'cmdecho cmde)
    )
    (if (and lwi (not (vlax-erased-p lwi)))
      (entdel lwi)
    )
    (if m
      (prompt m)
    )
    (princ)
  )

  (defun uniquelillst ( l )
    (if l (cons (car l) (uniquelillst (vl-remove-if (function (lambda ( x ) (vl-every (function (lambda ( z ) (vl-some (function (lambda ( q ) (or (and (equal (car q) (car z) 1e-6) (equal (cadr q) (cadr z) 1e-6)) (and (equal (car q) (cadr z) 1e-6) (equal (cadr q) (car z) 1e-6))))) (car l)))) x))) l))))
  )

  (defun unique ( l )
    (if l (cons (car l) (unique (vl-remove-if (function (lambda ( x ) (equal x (car l) 1e-6))) l))))
  )

  (defun unit ( v / d )
    (if (not (equal (setq d (distance (list 0.0 0.0 0.0) v)) 0.0 1e-8))
      (mapcar (function (lambda ( x ) (/ x d))) v)
    )
  )

  (defun mid ( p1 p2 )
    (mapcar (function (lambda ( a b ) (/ (+ a b) 2.0))) p1 p2)
  )

  (defun clockwise-p ( p1 p2 p3 )
    (minusp (sin (- (angle p1 p3) (angle p1 p2))))
  )

  (defun inside-p ( pt lw lwi )
    (< (distance pt (vlax-curve-getclosestpointto lwi pt)) (distance pt (vlax-curve-getclosestpointto lw pt)))
  )

  (defun distp2t ( p tt / i )
    (if (setq i (inters p (polar p (+ (angle (car tt) (cadr tt)) (* 0.5 pi)) 1.0) (car tt) (cadr tt) nil))
      (distance p i)
    )
  )

  (defun offsett2p ( p tt d / ip v v1 )
    (setq ip (inters p (polar p (+ (angle (car tt) (cadr tt)) (* 0.5 pi)) 1.0) (car tt) (cadr tt) nil))
    (setq v (mapcar (function -) p ip))
    (setq v1 (unit v))
    (list (mapcar (function +) (car tt) (mapcar (function *) v1 (list d d))) (mapcar (function +) (cadr tt) (mapcar (function *) v1 (list d d))))
  )

  (defun removesingles ( l / a )
    (while (setq a (vl-some (function (lambda ( x ) (if (= (1- (length l)) (length (vl-remove-if (function (lambda ( y ) (equal x y 1e-6))) l))) x))) l))
      (setq l (vl-remove-if (function (lambda ( x ) (equal x a 1e-6))) l))
    )
    l
  )

  (defun removedoubles ( l / a )
    (while (setq a (vl-some (function (lambda ( x ) (if (= (- (length l) 2) (length (vl-remove-if (function (lambda ( y ) (equal x y 1e-6))) l))) x))) l))
      (setq l (vl-remove-if (function (lambda ( x ) (equal x a 1e-6))) l))
    )
    l
  )

  (defun correctplanedist ( ip / d )
    (if (and (caar ip) (caadr ip) (cadadr ip) (caaddr ip) (cadr (caddr ip)) (equal (setq d (distp2t (caar ip) (cadr ip))) (distp2t (caar ip) (caddr ip)) 1e-6) d)
      d
    )
  )

  (defun collinear-p ( p1 p2 p3 )
    (
      (lambda ( a b c )
        (or
          (equal (+ a b) c 1e-10)
          (equal (+ b c) a 1e-10)
          (equal (+ c a) b 1e-10)
        )
      )
      (distance p1 p2) (distance p2 p3) (distance p1 p3)
    )
  )

  (defun unioncollinearplaneprints ( tl / a b tll )
    (while (setq a (car tl))
      (setq b (vl-remove-if-not (function (lambda ( x ) (and (collinear-p (car a) (cadr a) (car x)) (collinear-p (car a) (cadr a) (cadr x))))) tl))
      (setq tll (cons a tll))
      (if b
        (setq tl (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal x y 1e-6))) b))) tl))
        (setq tl (cdr tl))
      )
    )
    tll
  )

  (defun car-sort ( lst cmp / rtn )
    (setq rtn (car lst))
    (foreach itm (cdr lst)
      (if (apply cmp (list itm rtn))
        (setq rtn itm)
      )
    )
    rtn
  )

  (defun processtxtipl ( tl / ipl tl1 tl2 intt )
    (setq tl1 tl tl2 tl)
    (foreach t1 tl1
      (setq tl2 (cdr tl2))
      (foreach t2 tl2
        (if (setq intt (inters (car t1) (polar (car t1) (angle (car t1) (cadr t1)) 1.0) (car t2) (polar (car t2) (angle (car t2) (cadr t2)) 1.0) nil))
          (setq ipl (cons intt ipl))
          (setq ipl (cons (angle (car t1) (cadr t1)) ipl))
        )
      )
    )
    ipl
  )

  (defun chksolution ( errli / allplanesips anglst )
    (if (and (car errli) (cadr errli))
      (progn
        (setq allplanesips (processtxtipl tl))
        (setq allplanesips (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal x y 1e-6))) pl))) allplanesips))
        (setq anglst (vl-remove-if (function listp) allplanesips))
        (if (vl-some (function (lambda ( x ) (or (equal x 1e-8 1e-6) (equal x -1e-8 1e-6)))) anglst)
          (setq anglst (cons 0.0 anglst) anglst (cons pi anglst) anglst (cons (* 2 pi) anglst))
        )
        (setq allplanesips (vl-remove-if-not (function listp) allplanesips))
        (if (or
              (vl-some (function (lambda ( x ) (or
                                                 (equal (distance (car errli) (cadr errli)) (+ (distance (car errli) x) (distance x (cadr errli))) 1e-8)
                                                 (equal (distance (car errli) x) (+ (distance (car errli) (cadr errli)) (distance (cadr errli) x)) 1e-8)
                                                 (equal (distance (cadr errli) x) (+ (distance (cadr errli) (car errli)) (distance (car errli) x)) 1e-8)
                                               )
                                 )) allplanesips
              )
              (vl-some (function (lambda ( x ) (or (equal (angle (car errli) (cadr errli)) x 1e-8) (equal (angle (cadr errli) (car errli)) x 1e-8)))) anglst)
              (vl-some (function (lambda ( x ) (collinear-p (car errli) (cadr errli) x))) pl)
            )
          t
        )
      )
      t
    )
  )

  (defun test nil
    (and
      (not (vl-some (function (lambda ( x ) (and (not (vl-some (function (lambda ( y ) (inters (car x) (cadr x) (car y) (cadr y)))) lil)) (not (vl-some (function (lambda ( y ) (equal (distance (car y) (cadr y)) (+ (distance (car y) (polar (car x) (angle (car x) (cadr x)) 0.1)) (distance (polar (car x) (angle (car x) (cadr x)) 0.01) (cadr y))) 1e-6))) tl)) (inside-p (polar (car x) (angle (car x) (cadr x)) 0.01) lw lwi) (inside-p (polar (cadr x) (angle (cadr x) (car x)) 0.01) lw lwi)))) ll))
      (vl-every (function (lambda ( li ) (chksolution li))) lil)
      (vl-every (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal x y 1e-6))) (apply (function append) lil)))) pl)
      (not (vl-some (function (lambda ( li1 ) (vl-some (function (lambda ( li2 / ip ) (and (setq ip (inters (car li1) (cadr li1) (car li2) (cadr li2))) (not (equal ip (car li1) 1e-6)) (not (equal ip (cadr li1) 1e-6)) (not (equal ip (car li2) 1e-6)) (not (equal ip (cadr li2) 1e-6))))) (vl-remove li1 lil)))) lil))
    )
  )

  (defun chklili ( lil / lilpts )
    (setq lilpts (apply (function append) lil))
    (setq lilpts (vl-remove-if-not (function (lambda ( x ) (= (length (vl-remove-if (function (lambda (y) (equal x y 1e-6))) lilpts)) (- (length lilpts) 2)))) lilpts))
    lilpts
  )

  (defun findlinesbetweentl ( tl / ll tl1 tl2 )
    (setq tl1 tl tl2 tl)
    (foreach t1 tl1
      (setq tl2 (cdr tl2))
      (foreach t2 tl2
        (setq ll (cons (list (mid (car t1) (cadr t1)) (mid (car t2) (cadr t2))) ll))
      )
    )
    ll
  )

  (defun processipl ( pla / pla1 pla2 intt xx xxx xxxx uu ipl )
    (setq pla1 pla pla2 pla)
    (foreach p1 pla1
      (setq pla2 (cdr pla2))
      (foreach p2 pla2
        (setq intt (inters (caar p1) (polar (caar p1) (cadar p1) 1.0) (caar p2) (polar (caar p2) (cadar p2) 1.0) nil))
        (if (or (equal intt (caar p1) 1e-6) (equal intt (caar p2) 1e-6))
          (setq intt nil)
        )
        (if intt
          (if (setq xxx (vl-some (function (lambda ( x ) (if (= (length (vl-remove x (append (list (cadr p1) (caddr p1)) (list (cadr p2) (caddr p2))))) 2) x))) (append (list (cadr p1) (caddr p1)) (list (cadr p2) (caddr p2)))))
            (if (or (and (caadr p1) (cadadr p1) (caaddr p1) (cadr (caddr p1)) (or (equal (angle (caadr p1) (cadadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6) (equal (angle (cadadr p1) (caadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6)) (setq xx (vl-some (function (lambda ( x ) (if (equal x (mapcar (function +) intt (mapcar (function -) intt (caar p2))) 1e-6) x))) pl)) (or (equal (angle xx intt) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6) (equal (angle intt xx) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6))) (and (caadr p2) (cadadr p2) (caaddr p2) (cadr (caddr p2)) (or (equal (angle (caadr p2) (cadadr p2)) (angle (caaddr p2) (cadr (caddr p2))) 1e-6) (equal (angle (cadadr p2) (caadr p2)) (angle (caaddr p2) (cadr (caddr p2))) 1e-6)) (setq xx (vl-some (function (lambda ( x ) (if (equal x (mapcar (function +) intt (mapcar (function -) intt (caar p1))) 1e-6) x))) pl)) (or (equal (angle xx intt) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6) (equal (angle intt xx) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6))))
              (cond
                ( (and (caadr p1) (cadadr p1) (caaddr p1) (cadr (caddr p1)) (or (equal (angle (caadr p1) (cadadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6) (equal (angle (cadadr p1) (caadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6)))
                  (setq ipl (cons (list (list intt (if (setq xx (vl-remove xxx (list (cadr p2) (caddr p2)))) (angle (caar xx) (cadar xx)) (cadar p2))) (car xx) (if (and (caar xx) (cadar xx) (distp2t intt (car xx))) (offsett2p intt (car xx) (* (distp2t intt (car xx)) 2.0))) nil p1 p2) ipl))
                )
                ( t
                  (setq ipl (cons (list (list intt (if (setq xx (vl-remove xxx (list (cadr p1) (caddr p1)))) (angle (caar xx) (cadar xx)) (cadar p1))) (car xx) (if (and (caar xx) (cadar xx) (distp2t intt (car xx))) (offsett2p intt (car xx) (* (distp2t intt (car xx)) 2.0))) nil p1 p2) ipl))
                )
              )
              (setq ipl (cons (list (list intt (if (setq xxxx (if (and (setq xx (vl-remove xxx (append (list (cadr p1) (caddr p1)) (list (cadr p2) (caddr p2))))) (= (length xx) 2)) (inters (caar xx) (cadar xx) (caadr xx) (cadadr xx) nil))) (angle xxxx intt) (angle (caar xx) (cadar xx)))) (car xx) (cadr xx) xxx p1 p2) ipl))
            )
            (cond
              ( (or (and (caadr p1) (cadadr p1) (caaddr p1) (cadr (caddr p1)) (or (equal (angle (caadr p1) (cadadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6) (equal (angle (cadadr p1) (caadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6)) (setq xx (vl-some (function (lambda ( x ) (if (equal x (mapcar (function +) intt (mapcar (function -) intt (caar p2))) 1e-6) x))) pl)) (or (equal (angle xx intt) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6) (equal (angle intt xx) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6))) (and (caadr p2) (cadadr p2) (caaddr p2) (cadr (caddr p2)) (or (equal (angle (caadr p2) (cadadr p2)) (angle (caaddr p2) (cadr (caddr p2))) 1e-6) (equal (angle (cadadr p2) (caadr p2)) (angle (caaddr p2) (cadr (caddr p2))) 1e-6)) (setq xx (vl-some (function (lambda ( x ) (if (equal x (mapcar (function +) intt (mapcar (function -) intt (caar p1))) 1e-6) x))) pl)) (or (equal (angle xx intt) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6) (equal (angle intt xx) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6))))
                (cond
                  ( (and (caadr p1) (cadadr p1) (caaddr p1) (cadr (caddr p1)) (or (equal (angle (caadr p1) (cadadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6) (equal (angle (cadadr p1) (caadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6)))
                    (setq ipl (cons (list (list intt (if (setq xx (vl-remove xxx (list (cadr p2) (caddr p2)))) (angle (caar xx) (cadar xx)) (cadar p2))) (car xx) (if (and (caar xx) (cadar xx) (distp2t intt (car xx))) (offsett2p intt (car xx) (* (distp2t intt (car xx)) 2.0))) nil p1 p2) ipl))
                  )
                  ( t
                    (setq ipl (cons (list (list intt (if (setq xx (vl-remove xxx (list (cadr p1) (caddr p1)))) (angle (caar xx) (cadar xx)) (cadar p1))) (car xx) (if (and (caar xx) (cadar xx) (distp2t intt (car xx))) (offsett2p intt (car xx) (* (distp2t intt (car xx)) 2.0))) nil p1 p2) ipl))
                  )
                )
              )
              ( (= (length (setq uu (unioncollinearplaneprints (append (list (cadr p1) (caddr p1)) (list (cadr p2) (caddr p2)))))) 3)
                (foreach pp uu
                  (if (= (length (vl-remove-if-not (function (lambda ( x ) (or (equal pp x) (and (equal (distance (if (> (distance (car pp) (car x)) (distance (cadr pp) (car x))) (car pp) (cadr pp)) (car x)) (+ (distance (if (> (distance (car pp) (car x)) (distance (cadr pp) (car x))) (car pp) (cadr pp)) (if (> (distance (car pp) (car x)) (distance (cadr pp) (car x))) (cadr pp) (car pp))) (distance (if (> (distance (car pp) (car x)) (distance (cadr pp) (car x))) (cadr pp) (car pp)) (car x))) 1e-6) (equal (distance (if (> (distance (car pp) (cadr x)) (distance (cadr pp) (cadr x))) (car pp) (cadr pp)) (cadr x)) (+ (distance (if (> (distance (car pp) (cadr x)) (distance (cadr pp) (cadr x))) (car pp) (cadr pp)) (if (> (distance (car pp) (cadr x)) (distance (cadr pp) (cadr x))) (cadr pp) (car pp))) (distance (if (> (distance (car pp) (cadr x)) (distance (cadr pp) (cadr x))) (cadr pp) (car pp)) (cadr x))) 1e-6))))) (append (list (cadr p1) (caddr p1)) (list (cadr p2) (caddr p2))))) 2)
                    (setq xxx pp)
                  )
                )
                (setq ipl (cons (list (list intt (if (setq xxxx (if (and (setq xx (vl-remove xxx uu)) (= (length xx) 2)) (inters (caar xx) (cadar xx) (caadr xx) (cadadr xx) nil))) (angle xxxx intt) (angle (caar xx) (cadar xx)))) (car xx) (cadr xx) nil p1 p2) ipl))
              )
            )
          )
        )
      )
    )
    (setq ipl (vl-remove-if-not (function (lambda ( p / d1 d2 ) (and (inside-p (caar p) lw lwi) (removedoubles (removesingles (vl-remove nil (mapcar (function (lambda ( tt ) (distp2t (caar p) tt))) utl)))) (if (and (caadr p) (cadadr p) (caaddr p) (cadr (caddr p))) (or (and (setq d1 (distance (caar p) (vlax-curve-getclosestpointto lw (caar p)))) (setq d2 (correctplanedist p)) (> d1 d2)) (and d1 d2 (equal d1 d2 1e-6))) t)))) ipl))
  )

  (defun processipll ( / ip ipl1 ipl1l ipll dd )
    (foreach pla1 pla
      (setq ipl1l (vl-remove-if-not (function (lambda ( z ) (or (equal (angle (caar z) (caar pla1)) (cadar pla1) 1e-6) (equal (angle (caar pla1) (caar z)) (cadar pla1) 1e-6)))) ipl))
      ;;;(setq ipl1 (car-sort ipl1l (function (lambda ( a b ) (< (distance (caar a) (caar pla1)) (distance (caar b) (caar pla1)))))))
      (if (and lils (setq dd (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (or (equal (caar x) (car y) 1e-6) (equal (caar x) (cadr y) 1e-6)))) lils))) ipl1l)))
        (setq ipl1l dd)
      )
      ;|
      (setq ipl1 (car-sort ipl1l (function (lambda ( a b ) (if (equal (distance (caar a) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr a))))) (distance (caar b) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr b))))) 1e-6) (< (distance (caar a) (caar pla1)) (distance (caar b) (caar pla1))) (if (equal (distance (caar a) (caar pla1)) (distance (caar b) (caar pla1)) 1e-6) (< (distance (caar a) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr a))))) (distance (caar b) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr b)))))) (< (distance (caar a) (caar pla1)) (distance (caar b) (caar pla1)))))))))
      |;
      (setq ipl1 (car-sort ipl1l (function (lambda ( a b ) (if (equal (distance (caar a) (caar pla1)) (distance (caar b) (caar pla1)) 1e-6) (< (distance (caar a) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr a))))) (distance (caar b) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr b)))))) (if (equal (distance (caar a) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr a))))) (distance (caar b) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr b))))) 1e-6) (< (distance (caar a) (caar pla1)) (distance (caar b) (caar pla1))) (< (distance (caar a) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr a))))) (distance (caar b) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr b))))))))))))
      (setq ipl1 (car-sort ipl1l (function (lambda ( a b ) (< (distance (caar a) (caar pla1)) (distance (caar b) (caar pla1)))))))
      (setq ip nil)
      (if ipl1
        (vl-some (function (lambda ( x ) (or (setq ip (inters (polar (car x) (angle (car x) (cadr x)) 1e-3) (polar (cadr x) (angle (cadr x) (car x)) 1e-3) (caaar (cddddr ipl1)) (caar ipl1))) (setq ip (inters (polar (car x) (angle (car x) (cadr x)) 1e-3) (polar (cadr x) (angle (cadr x) (car x)) 1e-3) (caaadr (cddddr ipl1)) (caar ipl1)))))) tl)
      )
      (if (and ipl1 (not ip) (if (and (setq zzz (vl-some (function (lambda ( x ) (vl-some (function (lambda ( y ) (if (and (not (equal (caar x) (caar y) 1e-6)) (not (equal (caar x) (caar ipl1) 1e-6)) (not (equal (caar y) (caar ipl1) 1e-6)) (or (and (not (equal (caar y) (caaar (cddddr ipl1)) 1e-6)) (not (equal (caar x) (caaar (cddddr ipl1)) 1e-6)) (and (or (inters (caar y) (polar (caar y) (cadar y) 1e+6) (caaar (cddddr ipl1)) (caar ipl1)) (inters (caar y) (polar (caar y) (cadar y) -1e+6) (caaar (cddddr ipl1)) (caar ipl1))) (equal (caar x) (inters (caar y) (polar (caar y) (cadar y) 1.0) (caaar (cddddr ipl1)) (caar ipl1) nil) 1e-6))) (and (not (equal (caar y) (caaadr (cddddr ipl1)) 1e-6)) (not (equal (caar x) (caaadr (cddddr ipl1)) 1e-6)) (and (or (inters (caar y) (polar (caar y) (cadar y) 1e+6) (caaadr (cddddr ipl1)) (caar ipl1)) (inters (caar y) (polar (caar y) (cadar y) -1e+6) (caaadr (cddddr ipl1)) (caar ipl1))) (equal (caar x) (inters (caar y) (polar (caar y) (cadar y) 1.0) (caaadr (cddddr ipl1)) (caar ipl1) nil) 1e-6))))) (list x y)))) (append pla ipl)))) (append pla ipl))) (vl-some (function (lambda ( x ) (and (not (equal (caar x) (caaar zzz) 1e-6)) (not (equal (caar x) (caaadr zzz) 1e-6)) (equal (distance (caaar zzz) (caaadr zzz)) (+ (distance (caaar zzz) (caar x)) (distance (caar x) (caaadr zzz))) 1e-6)))) (append pla ipl))) t (not zzz)))
        (setq ipll (cons (vl-sort (vl-remove-if-not (function (lambda ( x ) (equal (caar ipl1) (caar x) 1e-6))) ipl) (function (lambda ( a b ) (< (max (distance (caar a) (caaar (cddddr a))) (distance (caar a) (caaadr (cddddr a)))) (max (distance (caar b) (caaar (cddddr b))) (distance (caar b) (caaadr (cddddr b)))))))) ipll))
      )
    )
    (if (vl-some (function (lambda ( x ) (equal (caar x) (cadar lil) 1e-6))) pla)
      (car-sort ipll (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b))) (equal c d 1e-6)) (< (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (if (or (null c) (null d)) (< (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (< c d))))))
      (if lil
        (car-sort ipll (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b))) (equal c d 1e-6)) (> (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (if (or (null c) (null d)) (> (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (< c d))))))
        (car-sort ipll (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b)))) (< c d) (< (distance (caaar a) (vlax-curve-getclosestpointto lw (caaar a))) (distance (caaar b) (vlax-curve-getclosestpointto lw (caaar b))))))))
      )
    )
  )

  (defun processplaa ( pla )
    (setq ipl (processipl (setq pla (vl-remove nil pla))))
    (processipll)
  )

  (defun processplaa-x ( pla )
    (setq ipl (processipl (setq pla (vl-remove nil pla))))
    (setq ipl (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal (caar x) y 1e-6))) (mapcar (function cadr) errlis)))) ipl))
    (processipll)
  )

  (defun process ( processplafun )
    (while (> n 0)
      (if (null plaa)
        (progn
          (setq ipl (processipl pla))
          (setq ipldl (mapcar (function (lambda ( x ) (list (correctplanedist x) x))) ipl))
          (setq pla1 (cadr (car-sort (vl-remove-if (function (lambda ( x ) (null (car x)))) ipldl) (function (lambda ( a b ) (if (equal (car a) (car b) 1e-6) (< (length (vl-remove-if-not (function (lambda ( x ) (equal (caaadr a) (caaadr x) 1e-6))) (vl-remove-if (function (lambda ( x ) (null (car x)))) ipldl))) (length (vl-remove-if-not (function (lambda ( x ) (equal (caaadr b) (caaadr x) 1e-6))) (vl-remove-if (function (lambda ( x ) (null (car x)))) ipldl)))) (< (car a) (car b))))))))
          (setq plaa (mapcar (function cadr) (vl-remove-if-not (function (lambda ( x ) (equal (caar pla1) (caaadr x) 1e-6))) (vl-remove-if (function (lambda ( x ) (null (car x)))) ipldl))))
          (setq plaa (list (car (vl-remove-if (function (lambda ( x ) (null (cadddr x)))) plaa))))
        )
        (if (equal plaa (setq plaa (unique (apply processplafun (list (setq pla (unique pla)))))) 1e-6)
          (setq n 0)
        )
      )
      (if plaa
        (foreach pla1 (reverse plaa)
          (if (not (vl-some (function (lambda ( x ) (equal pla1 x 1e-6))) pla))
            (setq pla (cons pla1 pla))
          )
        )
        (setq n 0)
      )
      (if plaa
        (if (= (length plaa) 1)
          (progn
            (setq x (caaar (cddddr (car plaa))))
            (setq y (caaadr (cddddr (car plaa))))
            (if (not (or (vl-some (function (lambda ( z ) (equal z (list x (caaar plaa)) 1e-6))) lil) (vl-some (function (lambda ( z ) (equal z (list (caaar plaa) x) 1e-6))) lil)))
              (if (not (equal x (caaar plaa) 1e-6))
                (progn
                  (setq lil (cons (list x (caaar plaa)) lil))
                  (setq pla (vl-remove-if (function (lambda ( z ) (equal x (caar z) 1e-6))) pla))
                )
              )
            )
            (if (not (or (vl-some (function (lambda ( z ) (equal z (list y (caaar plaa)) 1e-6))) lil) (vl-some (function (lambda ( z ) (equal z (list (caaar plaa) y) 1e-6))) lil)))
              (if (not (equal y (caaar plaa) 1e-6))
                (progn
                  (setq lil (cons (list y (caaar plaa)) lil))
                  (setq pla (vl-remove-if (function (lambda ( z ) (equal y (caar z) 1e-6))) pla))
                )
              )
            )
          )
          (foreach pla1 plaa
            (setq x (caaar (cddddr pla1)))
            (setq y (caaadr (cddddr pla1)))
            (if (not (or (vl-some (function (lambda ( z ) (equal z (list x (caar pla1)) 1e-6))) lil) (vl-some (function (lambda ( z ) (equal z (list (caar pla1) x) 1e-6))) lil)))
              (if (not (equal x (caar pla1) 1e-6))
                (progn
                  (setq lil (cons (list x (caar pla1)) lil))
                  (setq pla (vl-remove-if (function (lambda ( z ) (equal x (caar z) 1e-6))) pla))
                  (if (< 2 (length (unioncollinearplaneprints (unique (apply (function append) (mapcar (function (lambda ( x ) (list (list (caar x) (caaar (cddddr x))) (list (caar x) (caaadr (cddddr x)))))) plaa))))))
                    (setq pla (vl-remove-if (function (lambda ( z ) (equal (caar pla1) (caar z) 1e-6))) pla))
                  )
                )
              )
            )
            (if (not (or (vl-some (function (lambda ( z ) (equal z (list y (caar pla1)) 1e-6))) lil) (vl-some (function (lambda ( z ) (equal z (list (caar pla1) y) 1e-6))) lil)))
              (if (not (equal y (caar pla1) 1e-6))
                (progn
                  (setq lil (cons (list y (caar pla1)) lil))
                  (setq pla (vl-remove-if (function (lambda ( z ) (equal y (caar z) 1e-6))) pla))
                  (if (< 2 (length (unioncollinearplaneprints (unique (apply (function append) (mapcar (function (lambda ( x ) (list (list (caar x) (caaar (cddddr x))) (list (caar x) (caaadr (cddddr x)))))) plaa))))))
                    (setq pla (vl-remove-if (function (lambda ( z ) (equal (caar pla1) (caar z) 1e-6))) pla))
                  )
                )
              )
            )
          )
        )
      )
    )
  )

  (defun processipll-n ( / ip ipl1 ipl1l ipll zzz iplls iplls1 ipllx dd )
    (foreach pla1 pla
      (setq ipl1l (vl-remove-if-not (function (lambda ( z ) (or (equal (angle (caar z) (caar pla1)) (cadar pla1) 1e-6) (equal (angle (caar pla1) (caar z)) (cadar pla1) 1e-6)))) ipl))
      (if (and lils (setq dd (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (or (equal (caar x) (car y) 1e-6) (equal (caar x) (cadr y) 1e-6)))) lils))) ipl1l)))
        (setq ipl1l dd)
      )
      (setq ipl1 (car-sort ipl1l (function (lambda ( a b ) (if (equal (distance (caar a) (caar pla1)) (distance (caar b) (caar pla1)) 1e-6) (< (distance (caar a) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr a))))) (distance (caar b) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr b)))))) (if (equal (distance (caar a) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr a))))) (distance (caar b) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr b))))) 1e-6) (< (distance (caar a) (caar pla1)) (distance (caar b) (caar pla1))) (< (distance (caar a) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr a))))) (distance (caar b) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr b))))))))))))
      (setq ipl1 (car-sort ipl1l (function (lambda ( a b ) (< (distance (caar a) (caar pla1)) (distance (caar b) (caar pla1)))))))
      (setq ip nil)
      (if ipl1
        (vl-some (function (lambda ( x ) (or (setq ip (inters (polar (car x) (angle (car x) (cadr x)) 1e-3) (polar (cadr x) (angle (cadr x) (car x)) 1e-3) (caaar (cddddr ipl1)) (caar ipl1))) (setq ip (inters (polar (car x) (angle (car x) (cadr x)) 1e-3) (polar (cadr x) (angle (cadr x) (car x)) 1e-3) (caaadr (cddddr ipl1)) (caar ipl1)))))) tl)
      )
      (if
        (and
          ipl1
          (not ip)
          (if
            (and
              (setq zzz
                (vl-some (function (lambda ( x ) (vl-some (function (lambda ( y )
                  (if
                    (and
                      (not (equal (caar x) (caar y) 1e-6))
                      (not (equal (caar x) (caar ipl1) 1e-6))
                      (not (equal (caar y) (caar ipl1) 1e-6))
                      (or
                        (and
                          (not (equal (caar y) (caaar (cddddr ipl1)) 1e-6))
                          (not (equal (caar x) (caaar (cddddr ipl1)) 1e-6))
                          (and
                            (inters (polar (caar y) (cadar y) 1e+6) (polar (caar y) (cadar y) -1e+6) (caaar (cddddr ipl1)) (caar ipl1))
                            (equal (caar x) (inters (caar y) (polar (caar y) (cadar y) 1.0) (caaar (cddddr ipl1)) (caar ipl1) nil) 1e-6)
                          )
                        )
                        (and
                          (not (equal (caar y) (caaadr (cddddr ipl1)) 1e-6))
                          (not (equal (caar x) (caaadr (cddddr ipl1)) 1e-6))
                          (and
                            (inters (polar (caar y) (cadar y) 1e+6) (polar (caar y) (cadar y) -1e+6) (caaadr (cddddr ipl1)) (caar ipl1))
                            (equal (caar x) (inters (caar y) (polar (caar y) (cadar y) 1.0) (caaadr (cddddr ipl1)) (caar ipl1) nil) 1e-6)
                          )
                        )
                      )
                    ) (list x y)
                  ))) (if mode
                        (vl-remove-if (function (lambda ( z ) (vl-some (function (lambda ( q ) (equal q (caar z) 1e-6))) (apply (function append) lil)))) (append pla ipl))
                        (append pla ipl)
                      ))))
                      (if mode
                        (vl-remove-if (function (lambda ( z ) (vl-some (function (lambda ( q ) (equal q (caar z) 1e-6))) (apply (function append) lil)))) (append pla ipl))
                        (append pla ipl)
                      )
                )
              )
              (vl-some (function (lambda ( x )
                (and
                  (not (equal (caar x) (caaar zzz) 1e-6))
                  (not (equal (caar x) (caaadr zzz) 1e-6))
                  (equal (distance (caaar zzz) (caaadr zzz)) (+ (distance (caaar zzz) (caar x)) (distance (caar x) (caaadr zzz))) 1e-6)
                ))) (if mode
                      (vl-remove-if (function (lambda ( z ) (vl-some (function (lambda ( q ) (equal q (caar z) 1e-6))) (apply (function append) lil)))) (append pla ipl))
                      (append pla ipl)
                    )
              )
            )
            t
            (not zzz)
          )
        )
        (setq ipll (cons (vl-sort (vl-remove-if-not (function (lambda ( x ) (equal (caar ipl1) (caar x) 1e-6))) ipl) (function (lambda ( a b ) (< (max (distance (caar a) (caaar (cddddr a))) (distance (caar a) (caaadr (cddddr a)))) (max (distance (caar b) (caaar (cddddr b))) (distance (caar b) (caaadr (cddddr b)))))))) ipll))
      )
    )
    (if mode
      (setq ipllsort ipll)
    )
    (if (vl-some (function (lambda ( x ) (equal (caar x) (cadar lil) 1e-6))) pla)
      (if (setq ipllx (car-sort (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal (caar x) y 1e-6))) (append (apply (function append) errlis) (mapcar (function caar) plaal))))) ipll) (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b))) (equal c d 1e-6)) (< (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (if (or (null c) (null d)) (< (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (< c d)))))))
        (setq ipll ipllx)
        (if (setq ipllx (car-sort (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal (caar x) y 1e-6))) (apply (function append) errlis)))) ipll) (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b))) (equal c d 1e-6)) (< (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (if (or (null c) (null d)) (< (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (< c d)))))))
          (setq ipll ipllx)
          (if (setq ipllx (car-sort (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal (caar x) y 1e-6))) (mapcar (function caar) plaal)))) ipll) (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b))) (equal c d 1e-6)) (< (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (if (or (null c) (null d)) (< (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (< c d)))))))
            (setq ipll ipllx)
            (setq ipll (car-sort ipll (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b))) (equal c d 1e-6)) (< (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (if (or (null c) (null d)) (< (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (< c d)))))))
          )
        )
      )
      (if lil
        (if (setq ipllx (car-sort (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal (caar x) y 1e-6))) (append (apply (function append) errlis) (mapcar (function caar) plaal))))) ipll) (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b))) (equal c d 1e-6)) (> (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (if (or (null c) (null d)) (> (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (< c d)))))))
          (setq ipll ipllx)
          (if (setq ipllx (car-sort (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal (caar x) y 1e-6))) (apply (function append) errlis)))) ipll) (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b))) (equal c d 1e-6)) (> (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (if (or (null c) (null d)) (> (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (< c d)))))))
            (setq ipll ipllx)
            (if (setq ipllx (car-sort (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal (caar x) y 1e-6))) (mapcar (function caar) plaal)))) ipll) (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b))) (equal c d 1e-6)) (> (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (if (or (null c) (null d)) (> (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (< c d)))))))
              (setq ipll ipllx)
              (setq ipll (car-sort ipll (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b))) (equal c d 1e-6)) (> (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (if (or (null c) (null d)) (> (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (< c d)))))))
            )
          )
        )
        (car-sort ipll (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b)))) (< c d) (< (distance (caaar a) (vlax-curve-getclosestpointto lw (caaar a))) (distance (caaar b) (vlax-curve-getclosestpointto lw (caaar b))))))))
      )
    )
    ipll
  )

  (defun processplaa-n ( pla )
    (setq ipl (processipl (setq pla (vl-remove nil pla))))
    (setq ipl (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal (caar x) y 1e-6))) (mapcar (function cadr) errlis)))) ipl))
    (processipll-n)
  )

  (defun process-n ( processplafun )
    (while (and (> n 0) (null flag))
      (setq plaox pla lilxplaoxl nil)
      (if (null plaa)
        (progn
          (setq ipl (processipl pla))
          (setq ipldl (mapcar (function (lambda ( x ) (list (correctplanedist x) x))) ipl))
          (setq ipld (mapcar (function cadr) (vl-remove-if (function (lambda ( x ) (null (car x)))) ipldl)))
          (while (setq pla1 (car ipld))
            (setq ipldd (cons (vl-remove-if-not (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) ipld) ipldd))
            (setq ipld (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) ipld))
          )
          (setq maxlen (length (car-sort ipldd (function (lambda ( a b ) (> (length a) (length b)))))))
          (if (> maxlen 1)
            (setq mode t)
          )
          (setq pla1 (cadr (car-sort (vl-remove-if (function (lambda ( x ) (null (car x)))) ipldl) (function (lambda ( a b ) (if (equal (car a) (car b) 1e-6) (< (length (vl-remove-if-not (function (lambda ( x ) (equal (caaadr a) (caaadr x) 1e-6))) (vl-remove-if (function (lambda ( x ) (null (car x)))) ipldl))) (length (vl-remove-if-not (function (lambda ( x ) (equal (caaadr b) (caaadr x) 1e-6))) (vl-remove-if (function (lambda ( x ) (null (car x)))) ipldl)))) (< (car a) (car b))))))))
          (setq plaa (mapcar (function cadr) (vl-remove-if-not (function (lambda ( x ) (equal (caar pla1) (caaadr x) 1e-6))) (vl-remove-if (function (lambda ( x ) (null (car x)))) ipldl))))
          (setq plaa (list (car plaa)))
        )
        (if (equal plaa (setq plaa (unique (apply processplafun (list (setq pla (unique pla)))))) 1e-6)
          (setq n 0)
        )
      )
      (if plaa
        (setq plaal (cons plaa plaal))
      )
      (setq lil (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal x y 1e-6))) errlis))) lil))
      (setq closed (vl-remove-if-not (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal x y 1e-6))) lil))) closed))
      (if merrlis
        (if (and plaa (= (length plaa) 1))
          (progn
            (setq plaoxl (cons (list plaa plaox) plaoxl))
            (setq lill (cons (list plaa lil) lill))
          )
          (if plaa
            (foreach pla1 plaa
              (setq plaoxl (cons (list pla1 plaox) plaoxl))
              (setq lill (cons (list pla1 lil) lill))
            )
          )
        )
      )
      (if plaa
        (foreach pla1 (reverse plaa)
          (if (not (vl-some (function (lambda ( x ) (equal pla1 x 1e-6))) pla))
            (setq pla (cons pla1 pla))
          )
        )
        (progn
          (setq n (length utl))
          (if (and (test) (not (chklili lil)) (<= n (length lil)))
            (setq n 0)
            (progn
              (foreach pla1 pla
                (if (setq ip (vl-some (function (lambda ( x ) (if (or (equal (angle (caar pla1) x) (cadar pla1) 1e-6) (equal (angle x (caar pla1)) (cadar pla1) 1e-6)) x))) (mapcar (function cadr) lil)))
                  (if (and (not (vl-some (function (lambda ( z ) (equal z (list (caar pla1) ip) 1e-6))) lil)) (not (vl-some (function (lambda ( z ) (equal z (list ip (caar pla1)) 1e-6))) lil)))
                    (setq lil (cons (list (caar pla1) ip) lil))
                  )
                )
              )
              (if (and (test) (not (chklili lil)) (<= n (length lil)))
                (setq n 0)
                (progn
                  (setq op (vl-remove-if-not (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal (caar y) (cadr x) 1e-6))) pla))) closed))
                  (setq op (vl-some (function (lambda ( x ) (vl-some (function (lambda ( y ) (if (and (setq ip (inters (polar (caar y) (cadar y) 1e+6) (polar (caar y) (cadar y) -1e+6) (car x) (cadr x))) (not (equal ip (car x) 1e-6)) (not (equal ip (cadr x) 1e-6))) y))) pla))) op))
                  (setq op (vl-remove-if-not (function (lambda ( x ) (equal (caar op) (cadr x) 1e-6))) closed))
                  (if op
                    (setq errlis (append op errlis))
                  )
                  (setq flag t)
                )
              )
            )
          )
        )
      )
      (setq ff nil)
      (if plaa
        (if (= (length plaa) 1)
          (progn
            (setq x (caaar (cddddr (car plaa))))
            (setq y (caaadr (cddddr (car plaa))))
            (if (not (or (vl-some (function (lambda ( z ) (equal z (list x (caaar plaa)) 1e-6))) lil) (vl-some (function (lambda ( z ) (equal z (list (caaar plaa) x) 1e-6))) lil)))
              (progn
                (setq lilo lil errli nil)
                (while (setq errli (vl-some (function (lambda ( a ) (if (setq ip (inters x (caaar plaa) (car a) (cadr a))) a))) (setq lilo (vl-remove errli lilo))))
                  (if (and errli (not (equal ip x 1e-6)) (not (equal ip (caaar plaa) 1e-6)) (not (equal ip (car errli) 1e-6)) (not (equal ip (cadr errli) 1e-6)))
                    (setq errlis (cons errli errlis) errlis (cons (list x (caaar plaa)) errlis) plaox (cadr (vl-some (function (lambda ( x ) (if (or (equal (car errli) (caaar (cddddr (caar x))) 1e-6) (equal (car errli) (caaadr (cddddr (caar x))) 1e-6)) x))) (reverse plaoxl))) lilx (cadr (vl-some (function (lambda ( x ) (if (or (equal (car errli) (caaar (cddddr (caar x))) 1e-6) (equal (car errli) (caaadr (cddddr (caar x))) 1e-6)) x))) (reverse lill))) lilxplaoxl (cons (list lilx plaox) lilxplaoxl) flag t)
                  )
                )
                (if (and (null flag) (not (equal x (caaar plaa) 1e-6)))
                  (progn
                    (if (and mode (setq ip (vl-some (function (lambda ( z ) (if (and (equal (distance x (caaar plaa)) (+ (distance x (caaar z)) (distance (caaar z) (caaar plaa))) 1e-6) (not (equal x (caaar z) 1e-6)) (not (equal (caaar plaa) (caaar z) 1e-6))) (caaar z)))) ipllsort)))
                      (if (and ip (not (vl-some (function (lambda ( z ) (equal z (list x ip) 1e-6))) lil)) (not (vl-some (function (lambda ( z ) (equal z (list ip (caaar plaa)) 1e-6))) lil)))
                        (setq lil (cons (list x ip) lil) lil (cons (list ip (caaar plaa)) lil))
                        (if (not ip)
                          (setq lil (cons (list x (caaar plaa)) lil))
                        )
                      )
                      (setq lil (cons (list x (caaar plaa)) lil))
                    )
                    (setq pla (vl-remove-if (function (lambda ( z ) (equal x (caar z) 1e-6))) pla))
                    (setq closed (cons (list x (caaar plaa)) closed))
                  )
                )
              )
            )
            (if (not (or (vl-some (function (lambda ( z ) (equal z (list y (caaar plaa)) 1e-6))) lil) (vl-some (function (lambda ( z ) (equal z (list (caaar plaa) y) 1e-6))) lil)))
              (progn
                (setq lilo lil errli nil)
                (while (setq errli (vl-some (function (lambda ( a ) (if (setq ip (inters y (caaar plaa) (car a) (cadr a))) a))) (setq lilo (vl-remove errli lilo))))
                  (if (and errli (not (equal ip y 1e-6)) (not (equal ip (caaar plaa) 1e-6)) (not (equal ip (car errli) 1e-6)) (not (equal ip (cadr errli) 1e-6)))
                    (setq errlis (cons errli errlis) errlis (cons (list y (caaar plaa)) errlis) plaox (cadr (vl-some (function (lambda ( x ) (if (or (equal (car errli) (caaar (cddddr (caar x))) 1e-6) (equal (car errli) (caaadr (cddddr (caar x))) 1e-6)) x))) (reverse plaoxl))) lilx (cadr (vl-some (function (lambda ( x ) (if (or (equal (car errli) (caaar (cddddr (caar x))) 1e-6) (equal (car errli) (caaadr (cddddr (caar x))) 1e-6)) x))) (reverse lill))) lilxplaoxl (cons (list lilx plaox) lilxplaoxl) flag t)
                  )
                )
                (if (and (null flag) (not (equal y (caaar plaa) 1e-6)))
                  (progn
                    (if (and mode (setq ip (vl-some (function (lambda ( z ) (if (and (equal (distance y (caaar plaa)) (+ (distance y (caaar z)) (distance (caaar z) (caaar plaa))) 1e-6) (not (equal y (caaar z) 1e-6)) (not (equal (caaar plaa) (caaar z) 1e-6))) (caaar z)))) ipllsort)))
                      (if (and ip (not (vl-some (function (lambda ( z ) (equal z (list y ip) 1e-6))) lil)) (not (vl-some (function (lambda ( z ) (equal z (list ip (caaar plaa)) 1e-6))) lil)))
                        (setq lil (cons (list y ip) lil) lil (cons (list ip (caaar plaa)) lil))
                        (if (not ip)
                          (setq lil (cons (list y (caaar plaa)) lil))
                        )
                      )
                      (setq lil (cons (list y (caaar plaa)) lil))
                    )
                    (setq pla (vl-remove-if (function (lambda ( z ) (equal y (caar z) 1e-6))) pla))
                    (setq closed (cons (list y (caaar plaa)) closed))
                  )
                )
              )
            )
            (if (vl-some (function (lambda ( z ) (equal (caaar plaa) z 1e-6))) (mapcar (function car) lil))
              (progn
                (setq pla (vl-remove-if (function (lambda ( z ) (equal x (caar z) 1e-6))) pla))
                (setq pla (vl-remove-if (function (lambda ( z ) (equal y (caar z) 1e-6))) pla))
                (setq pla (vl-remove-if (function (lambda ( z ) (equal (caaar plaa) (caar z) 1e-6))) pla))
              )
            )
          )
          (foreach pla1 plaa
            (setq x (caaar (cddddr pla1)))
            (setq y (caaadr (cddddr pla1)))
            (if (not (or (vl-some (function (lambda ( z ) (equal z (list x (caar pla1)) 1e-6))) lil) (vl-some (function (lambda ( z ) (equal z (list (caar pla1) x) 1e-6))) lil)))
              (progn
                (setq lilo lil errli nil)
                (while (setq errli (vl-some (function (lambda ( a ) (if (setq ip (inters x (caar pla1) (car a) (cadr a))) a))) (setq lilo (vl-remove errli lilo))))
                  (if (and errli (not (equal ip x 1e-6)) (not (equal ip (caar pla1) 1e-6)) (not (equal ip (car errli) 1e-6)) (not (equal ip (cadr errli) 1e-6)))
                    (setq errlis (cons errli errlis) errlis (cons (list x (caar pla1)) errlis) plaox (cadr (vl-some (function (lambda ( x ) (if (or (equal (car errli) (caaar (cddddr (caar x))) 1e-6) (equal (car errli) (caaadr (cddddr (caar x))) 1e-6)) x))) (reverse plaoxl))) lilx (cadr (vl-some (function (lambda ( x ) (if (or (equal (car errli) (caaar (cddddr (caar x))) 1e-6) (equal (car errli) (caaadr (cddddr (caar x))) 1e-6)) x))) (reverse lill))) lilxplaoxl (cons (list lilx plaox) lilxplaoxl) flag t)
                  )
                )
                (if (and (null flag) (not (equal x (caar pla1) 1e-6)))
                  (progn
                    (if (and mode (setq ip (vl-some (function (lambda ( z ) (if (and (equal (distance x (caar pla1)) (+ (distance x (caaar z)) (distance (caaar z) (caar pla1))) 1e-6) (not (equal x (caaar z) 1e-6)) (not (equal (caar pla1) (caaar z) 1e-6))) (caaar z)))) ipllsort)))
                      (if (and ip (not (vl-some (function (lambda ( z ) (equal z (list x ip) 1e-6))) lil)) (not (vl-some (function (lambda ( z ) (equal z (list ip (caar pla1)) 1e-6))) lil)))
                        (setq lil (cons (list x ip) lil) lil (cons (list ip (caar pla1)) lil))
                        (if (not ip)
                          (setq lil (cons (list x (caar pla1)) lil))
                        )
                      )
                      (setq lil (cons (list x (caar pla1)) lil))
                    )
                    (if (/= 3 (length (unique (apply (function append) (mapcar (function (lambda ( x ) (list (list (caar x) (caaar (cddddr x))) (list (caar x) (caaadr (cddddr x)))))) plaa)))))
                      (setq pla (vl-remove-if (function (lambda ( z ) (equal x (caar z) 1e-6))) pla))
                      (if (and (= 3 (length (unique (apply (function append) (mapcar (function (lambda ( x ) (list (list (caar x) (caaar (cddddr x))) (list (caar x) (caaadr (cddddr x)))))) plaa))))) (null (cadddr (car plaa))))
                        (setq pla (vl-remove-if (function (lambda ( z ) (equal x (caar z) 1e-6))) pla))
                      )
                    )
                    (setq closed (cons (list x (caar pla1)) closed))
                  )
                )
              )
            )
            (if (not (or (vl-some (function (lambda ( z ) (equal z (list y (caar pla1)) 1e-6))) lil) (vl-some (function (lambda ( z ) (equal z (list (caar pla1) y) 1e-6))) lil)))
              (progn
                (setq lilo lil errli nil)
                (while (setq errli (vl-some (function (lambda ( a ) (if (setq ip (inters y (caar pla1) (car a) (cadr a))) a))) (setq lilo (vl-remove errli lilo))))
                  (if (and errli (not (equal ip y 1e-6)) (not (equal ip (caar pla1) 1e-6)) (not (equal ip (car errli) 1e-6)) (not (equal ip (cadr errli) 1e-6)))
                    (setq errlis (cons errli errlis) errlis (cons (list y (caar pla1)) errlis) plaox (cadr (vl-some (function (lambda ( x ) (if (or (equal (car errli) (caaar (cddddr (caar x))) 1e-6) (equal (car errli) (caaadr (cddddr (caar x))) 1e-6)) x))) (reverse plaoxl))) lilx (cadr (vl-some (function (lambda ( x ) (if (or (equal (car errli) (caaar (cddddr (caar x))) 1e-6) (equal (car errli) (caaadr (cddddr (caar x))) 1e-6)) x))) (reverse lill))) lilxplaoxl (cons (list lilx plaox) lilxplaoxl) flag t)
                  )
                )
                (if (and (null flag) (not (equal y (caar pla1) 1e-6)))
                  (progn
                    (if (and mode (setq ip (vl-some (function (lambda ( z ) (if (and (equal (distance y (caar pla1)) (+ (distance y (caaar z)) (distance (caaar z) (caar pla1))) 1e-6) (not (equal y (caaar z) 1e-6)) (not (equal (caar pla1) (caaar z) 1e-6))) (caaar z)))) ipllsort)))
                      (if (and ip (not (vl-some (function (lambda ( z ) (equal z (list y ip) 1e-6))) lil)) (not (vl-some (function (lambda ( z ) (equal z (list ip (caar pla1)) 1e-6))) lil)))
                        (setq lil (cons (list y ip) lil) lil (cons (list ip (caar pla1)) lil))
                        (if (not ip)
                          (setq lil (cons (list y (caar pla1)) lil))
                        )
                      )
                      (setq lil (cons (list y (caar pla1)) lil))
                    )
                    (if (/= 3 (length (unique (apply (function append) (mapcar (function (lambda ( x ) (list (list (caar x) (caaar (cddddr x))) (list (caar x) (caaadr (cddddr x)))))) plaa)))))
                      (setq pla (vl-remove-if (function (lambda ( z ) (equal y (caar z) 1e-6))) pla))
                      (if (and (= 3 (length (unique (apply (function append) (mapcar (function (lambda ( x ) (list (list (caar x) (caaar (cddddr x))) (list (caar x) (caaadr (cddddr x)))))) plaa))))) (null (cadddr (car plaa))))
                        (setq pla (vl-remove-if (function (lambda ( z ) (equal y (caar z) 1e-6))) pla))
                      )
                    )
                    (setq closed (cons (list y (caar pla1)) closed))
                  )
                )
              )
            )
            (if (< 2 (length (unioncollinearplaneprints (unique (apply (function append) (mapcar (function (lambda ( x ) (list (list (caar x) (caaar (cddddr x))) (list (caar x) (caaadr (cddddr x)))))) plaa))))))
              (setq pla (vl-remove-if (function (lambda ( z ) (vl-some (function (lambda ( x ) (equal (caar x) (caar z) 1e-6))) plaa))) pla))
              (if (and (null ff) (= 3 (length (unique (apply (function append) (mapcar (function (lambda ( x ) (list (list (caar x) (caaar (cddddr x))) (list (caar x) (caaadr (cddddr x)))))) plaa))))) (not (null (cadddr (car plaa)))))
                (progn
                  (setq xxx (vl-some (function (lambda ( x ) (if (= (length (vl-remove x (apply (function append) (mapcar (function (lambda ( x ) (list (list (caar x) (caaar (cddddr x))) (list (caar x) (caaadr (cddddr x)))))) plaa)))) 2) x))) (apply (function append) (mapcar (function (lambda ( x ) (list (list (caar x) (caaar (cddddr x))) (list (caar x) (caaadr (cddddr x)))))) plaa))))
                  (setq xxxx (vl-some (function (lambda ( x ) (if (equal (caar x) (cadr xxx) 1e-6) x))) pla))
                  (setq x1 (car plaa) x2 (cadr plaa))
                  (setq xxxx1 (car (vl-remove xxxx (cddddr x1))) xxxx2 (car (vl-remove xxxx (cddddr x2))))
                  (setq xxx1 (car (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal x y 1e-6))) (list (cadr xxxx) (caddr xxxx))))) (list (cadr x1) (caddr x1)))))
                  (setq xxx2 (car (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal x y 1e-6))) (list (cadr xxxx) (caddr xxxx))))) (list (cadr x2) (caddr x2)))))
                  (setq xx (list (list (caar x1) (cadar xxxx)) xxx1 xxx2 nil xxxx1 xxxx2))
                  (setq pla (vl-remove x1 pla) pla (vl-remove x2 pla))
                  (setq pla (vl-remove-if (function (lambda ( z ) (equal (caar xxxx) (caar z) 1e-6))) pla))
                  (setq pla (vl-remove-if (function (lambda ( z ) (equal x (caar z) 1e-6))) pla))
                  (setq pla (vl-remove-if (function (lambda ( z ) (equal y (caar z) 1e-6))) pla))
                  (setq pla (cons xx pla))
                  (setq ff t)
                )
              )
            )
            (if (vl-some (function (lambda ( z ) (equal (caar pla1) z 1e-6))) (mapcar (function car) lil))
              (progn
                (setq pla (vl-remove-if (function (lambda ( z ) (equal x (caar z) 1e-6))) pla))
                (setq pla (vl-remove-if (function (lambda ( z ) (equal y (caar z) 1e-6))) pla))
                (setq pla (vl-remove-if (function (lambda ( z ) (equal (caar pla1) (caar z) 1e-6))) pla))
              )
            )
          )
        )
        (if merrlis
          (setq flag t fflag t)
        )
      )
    )
  )

  (defun postprocess ( / chk )
    (setq flag t loop t lil nil plaa nil pla plao merrlis t)
    (while (and flag loop)
      (setq n (length utl) flag nil)
      (process-n (function processplaa-n))
      (if fflag
        (setq flag nil)
      )
      (if (and lilxplaoxl (null fflag))
        (setq lilxplaoxl (reverse lilxplaoxl) lilxplaoxl (vl-some (function (lambda ( x ) (if (= (length (car x)) (apply (function min) (mapcar (function length) (mapcar (function car) lilxplaoxl)))) x))) lilxplaoxl) lil (car lilxplaoxl) pla (cadr lilxplaoxl) plaa (caadr (vl-member-if (function (lambda ( x ) (equal pla (cadr x) 1e-6))) plaoxl)) lill (vl-member-if (function (lambda ( x ) (equal plaa (car x) 1e-6))) lill) plaoxl (vl-member-if (function (lambda ( x ) (equal plaa (car x) 1e-6))) plaoxl) lilxplaoxl nil)
      )
    )
    (if (null flag)
      (if (and (caaar pla) (caaadr pla) (not (equal (caaar pla) (caaadr pla) 1e-6)) (chksolution (list (caaar pla) (caaadr pla))) (not (vl-some (function (lambda ( x ) (or (equal (caaar pla) (caar x) 1e-6) (equal (caaadr pla) (caar x) 1e-6)))) plao)))
        (setq lil (cons (list (caaadr pla) (caaar pla)) lil))
        (if (and (caaar pla) (caaadr pla) (not (equal (caaar pla) (caaadr pla) 1e-6)))
          (progn
            (setq x (car-sort (vl-remove-if-not (function (lambda ( x ) (or (equal (angle (caaar pla) x) (cadaar pla) 1e-6) (equal (angle x (caaar pla)) (cadaar pla) 1e-6)))) (apply (function append) lil)) (function (lambda ( a b ) (< (distance (caaar pla) a) (distance (caaar pla) b))))))
            (if (and x (chksolution (list x (caaar pla))) (not (vl-some (function (lambda ( z ) (or (equal z (list x (caaar pla)) 1e-6) (equal z (list (caaar pla) x) 1e-6)))) lil)) (not (vl-some (function (lambda ( x ) (equal (caaar pla) (caar x) 1e-6))) plao)))
              (setq lil (cons (list x (caaar pla)) lil))
            )
            (setq y (car-sort (vl-remove-if-not (function (lambda ( x ) (or (equal (angle (caaadr pla) x) (cadar (cadr pla)) 1e-6) (equal (angle x (caaadr pla)) (cadar (cadr pla)) 1e-6)))) (apply (function append) lil)) (function (lambda ( a b ) (< (distance (caaadr pla) a) (distance (caaadr pla) b))))))
            (if (and y (chksolution (list y (caaadr pla))) (not (vl-some (function (lambda ( z ) (or (equal z (list y (caaadr pla)) 1e-6) (equal z (list (caaadr pla) y) 1e-6)))) lil)) (not (vl-some (function (lambda ( x ) (equal (caaadr pla) (caar x) 1e-6))) plao)))
              (setq lil (cons (list y (caaadr pla)) lil))
            )
          )
        )
      )
    )
    (setq lil (vl-remove-if (function (lambda ( x ) (equal (car x) (cadr x) 1e-6))) lil))
    (setq n (length utl))
    (if (and (test) (not (chklili lil)) (<= n (length lil)))
      (progn
        (setq lillst (cons lil lillst))
        (setq chk t)
      )
    )
    (if (null chk)
      (progn
        (setq flag t loop t plaal nil fflag nil merrlis nil)
        (while (and flag loop)
          (setq lil nil n (length utl) pla plao plaa nil flag nil closed nil)
          (process-n (function processplaa-n))
          (if fflag
            (setq flag nil)
          )
          (if (equal liloo lil 1e-6)
            (setq errlis (reverse (cdr (reverse (unique errlis)))))
            (setq liloo lil)
          )
          (if (and flag (null errlis))
            (setq loop nil)
          )
        )
        (if (or (null flag) (null loop))
          (progn
            (if (and (caaar pla) (caaadr pla) (not (equal (caaar pla) (caaadr pla) 1e-6)) (chksolution (list (caaar pla) (caaadr pla))) (not (vl-some (function (lambda ( x ) (or (equal (caaar pla) (caar x) 1e-6) (equal (caaadr pla) (caar x) 1e-6)))) plao)))
              (setq lil (cons (list (caaadr pla) (caaar pla)) lil))
              (if (and (caaar pla) (caaadr pla) (not (equal (caaar pla) (caaadr pla) 1e-6)))
                (progn
                  (setq x (car-sort (vl-remove-if-not (function (lambda ( x ) (or (equal (angle (caaar pla) x) (cadaar pla) 1e-6) (equal (angle x (caaar pla)) (cadaar pla) 1e-6)))) (apply (function append) lil)) (function (lambda ( a b ) (< (distance (caaar pla) a) (distance (caaar pla) b))))))
                  (if (and x (chksolution (list x (caaar pla))) (not (vl-some (function (lambda ( z ) (or (equal z (list x (caaar pla)) 1e-6) (equal z (list (caaar pla) x) 1e-6)))) lil)) (not (vl-some (function (lambda ( x ) (equal (caaar pla) (caar x) 1e-6))) plao)))
                    (setq lil (cons (list x (caaar pla)) lil))
                  )
                  (setq y (car-sort (vl-remove-if-not (function (lambda ( x ) (or (equal (angle (caaadr pla) x) (cadar (cadr pla)) 1e-6) (equal (angle x (caaadr pla)) (cadar (cadr pla)) 1e-6)))) (apply (function append) lil)) (function (lambda ( a b ) (< (distance (caaadr pla) a) (distance (caaadr pla) b))))))
                  (if (and y (chksolution (list y (caaadr pla))) (not (vl-some (function (lambda ( z ) (or (equal z (list y (caaadr pla)) 1e-6) (equal z (list (caaadr pla) y) 1e-6)))) lil)) (not (vl-some (function (lambda ( x ) (equal (caaadr pla) (caar x) 1e-6))) plao)))
                    (setq lil (cons (list y (caaadr pla)) lil))
                  )
                )
              )
            )
            (setq lil (vl-remove-if (function (lambda ( x ) (equal (car x) (cadr x) 1e-6))) lil))
            (setq n (length utl))
            (if (and (test) (not (chklili lil)) (<= n (length lil)))
              (progn
                (setq lillst (cons lil lillst))
                (setq loop nil chk t)
              )
            )
          )
        )
      )
    )
  )

  (setq cmde (getvar 'cmdecho))
  (setvar 'cmdecho 0)
  (vl-cmdf "_.UNDO" "_BE")
  (prompt "\nPick a closed polygonal LWPOLYLINE...")
  (if (setq s (ssget "_+.:E:S" '((0 . "LWPOLYLINE") (-4 . "&=") (70 . 1) (-4 . "<not") (-4 . "<>") (42 . 0.0) (-4 . "not>"))))
    (progn
      (while (null lils)
        (prompt "\nSelect initial solution...")
        (setq lils (ssget '((0 . "LINE"))))
      )
      (setq lils (mapcar (function (lambda ( x ) (mapcar (function (lambda ( y ) (mapcar (function +) (list 0.0 0.0) (cdr y)))) (vl-remove-if-not (function (lambda ( z ) (vl-position (car z) (list 10 11)))) (entget x))))) (vl-remove-if (function listp) (mapcar (function cadr) (ssnamex lils)))))
      (setq lillst (cons lils lillst))
      (setq ti (car (_vl-times)))
      (if (= 0 (getvar 'worlducs))
        (vl-cmdf "_.UCS" "_W")
      )
      (setq lwx (entget (setq lw (ssname s 0))))
      (setq lwi (vlax-vla-object->ename (car (vlax-invoke (vlax-ename->vla-object lw) 'offset 0.001))))
      (if (< (vlax-curve-getarea lw) (vlax-curve-getarea lwi))
        (progn
          (entdel lwi)
          (setq lwi (vlax-vla-object->ename (car (vlax-invoke (vlax-ename->vla-object lw) 'offset -0.001))))
        )
      )
      (setq pl (mapcar (function (lambda ( p ) (mapcar (function +) (list 0 0) (trans p lw 0)))) (mapcar (function cdr) (vl-remove-if (function (lambda ( x ) (/= (car x) 10))) lwx))))
      (setq pl (append pl (list (car pl))))
      (setq tl (mapcar (function (lambda ( a b ) (list a b))) (reverse (cdr (reverse pl))) (cdr pl)))
      (setq pla (mapcar (function (lambda ( p mp ) (list p (angle p mp)))) pl (mapcar (function (lambda ( a b ) (cond ( (collinear-p (car a) (car b) (cadr b)) (vlax-curve-getclosestpointto lwi (car b)) ) ( t (if (clockwise-p (car a) (car b) (cadr b)) (mid (polar (cadr a) (angle (cadr a) (car a)) -1.0) (polar (car b) (angle (car b) (cadr b)) -1.0)) (mid (polar (cadr a) (angle (cadr a) (car a)) 1.0) (polar (car b) (angle (car b) (cadr b)) 1.0))) )))) (cons (last tl) tl) tl)))
      (setq pla (mapcar (function (lambda ( a pla b ) (list pla a b))) (cons (last tl) tl) pla tl))
      (setq plao pla)
      (setq dx (- (car (car-sort pl (function (lambda ( a b ) (> (car a) (car b)))))) (car (car-sort pl (function (lambda ( a b ) (< (car a) (car b))))))))
      (while (or (null (cadr lillst)) (or (not (setq chk (vl-some (function (lambda ( x ) (/= (length (vl-remove-if (function (lambda ( y ) (vl-every (function (lambda ( z ) (vl-some (function (lambda ( q ) (or (and (equal (car q) (car z) 1e-6) (equal (cadr q) (cadr z) 1e-6)) (and (equal (car q) (cadr z) 1e-6) (equal (cadr q) (car z) 1e-6))))) x))) y))) lillst)) (1- (length lillst))))) lillst))) (and chk (null lils))) (not (vl-every (function (lambda ( x ) (vl-some (function (lambda ( y ) (vl-every (function (lambda ( z ) (vl-some (function (lambda ( q ) (or (and (equal (car q) (car z) 1e-6) (equal (cadr q) (cadr z) 1e-6)) (and (equal (car q) (cadr z) 1e-6) (equal (cadr q) (car z) 1e-6))))) x))) y))) lillsto))) lillst)))
        (setq ll (findlinesbetweentl tl))
        (setq n (length (setq utl (unioncollinearplaneprints tl))))
        (setq lil nil pla plao lillsto lillst)
        (process (function processplaa))
        (if (and (caaar pla) (caaadr pla) (not (equal (caaar pla) (caaadr pla) 1e-6)) (chksolution (list (caaar pla) (caaadr pla))))
          (setq lil (cons (list (caaadr pla) (caaar pla)) lil))
          (if (and (caaar pla) (caaadr pla) (not (equal (caaar pla) (caaadr pla) 1e-6)))
            (progn
              (setq x (car-sort (vl-remove-if-not (function (lambda ( x ) (or (equal (angle (caaar pla) x) (cadaar pla) 1e-6) (equal (angle x (caaar pla)) (cadaar pla) 1e-6)))) (apply (function append) lil)) (function (lambda ( a b ) (< (distance (caaar pla) a) (distance (caaar pla) b))))))
              (if (and x (chksolution (list x (caaar pla))) (not (vl-some (function (lambda ( z ) (or (equal z (list x (caaar pla)) 1e-6) (equal z (list (caaar pla) x) 1e-6)))) lil)))
                (setq lil (cons (list x (caaar pla)) lil))
              )
              (setq y (car-sort (vl-remove-if-not (function (lambda ( x ) (or (equal (angle (caaadr pla) x) (cadar (cadr pla)) 1e-6) (equal (angle x (caaadr pla)) (cadar (cadr pla)) 1e-6)))) (apply (function append) lil)) (function (lambda ( a b ) (< (distance (caaadr pla) a) (distance (caaadr pla) b))))))
              (if (and y (chksolution (list y (caaadr pla))) (not (vl-some (function (lambda ( z ) (or (equal z (list y (caaadr pla)) 1e-6) (equal z (list (caaadr pla) y) 1e-6)))) lil)))
                (setq lil (cons (list y (caaadr pla)) lil))
              )
            )
          )
        )
        (setq lil (vl-remove-if (function (lambda ( x ) (equal (car x) (cadr x) 1e-6))) lil))
        (setq lixl (vl-remove-if-not (function (lambda ( x ) (> (length (vl-remove-if-not (function (lambda ( y ) (and (setq ip (inters (car x) (cadr x) (car y) (cadr y))) (not (equal ip (car x) 1e-6)) (not (equal ip (cadr x) 1e-6)) (not (equal ip (car y) 1e-6)) (not (equal ip (cadr y) 1e-6))))) (vl-remove x lil))) 1))) lil))
        (foreach lix lixl
          (foreach li (vl-remove lix lil)
            (if (and (setq ip (inters (car lix) (cadr lix) (car li) (cadr li))) (not (equal ip (car lix) 1e-6)) (not (equal ip (cadr lix) 1e-6)) (not (equal ip (car li) 1e-6)) (not (equal ip (cadr li) 1e-6)))
              (setq errlis (cons li errlis))
            )
          )
        )
        (setq n (length utl))
        (if (and (test) (not (chklili lil)) (<= n (length lil)))
          (setq lillst (cons lil lillst))
          (if errlis
            (progn
              (setq lil nil n (length utl) pla plao plaa nil)
              (process (function processplaa-x))
              (if (and (caaar pla) (caaadr pla) (not (equal (caaar pla) (caaadr pla) 1e-6)) (chksolution (list (caaar pla) (caaadr pla))))
                (setq lil (cons (list (caaadr pla) (caaar pla)) lil))
                (if (and (caaar pla) (caaadr pla) (not (equal (caaar pla) (caaadr pla) 1e-6)))
                  (progn
                    (setq x (car-sort (vl-remove-if-not (function (lambda ( x ) (or (equal (angle (caaar pla) x) (cadaar pla) 1e-6) (equal (angle x (caaar pla)) (cadaar pla) 1e-6)))) (apply (function append) lil)) (function (lambda ( a b ) (< (distance (caaar pla) a) (distance (caaar pla) b))))))
                    (if (and x (chksolution (list x (caaar pla))) (not (vl-some (function (lambda ( z ) (or (equal z (list x (caaar pla)) 1e-6) (equal z (list (caaar pla) x) 1e-6)))) lil)))
                      (setq lil (cons (list x (caaar pla)) lil))
                    )
                    (setq y (car-sort (vl-remove-if-not (function (lambda ( x ) (or (equal (angle (caaadr pla) x) (cadar (cadr pla)) 1e-6) (equal (angle x (caaadr pla)) (cadar (cadr pla)) 1e-6)))) (apply (function append) lil)) (function (lambda ( a b ) (< (distance (caaadr pla) a) (distance (caaadr pla) b))))))
                    (if (and y (chksolution (list y (caaadr pla))) (not (vl-some (function (lambda ( z ) (or (equal z (list y (caaadr pla)) 1e-6) (equal z (list (caaadr pla) y) 1e-6)))) lil)))
                      (setq lil (cons (list y (caaadr pla)) lil))
                    )
                  )
                )
              )
              (setq lil (vl-remove-if (function (lambda ( x ) (equal (car x) (cadr x) 1e-6))) lil))
              (setq errlis nil)
              (setq n (length utl))
              (if (and (test) (not (chklili lil)) (<= n (length lil)))
                (setq lillst (cons lil lillst))
                (postprocess)
              )
            )
            (postprocess)
          )
        )
        (if (cdr lillst)
          (cond
            ( (and (not fff) (vl-some (function (lambda ( x ) (vl-every (function (lambda ( y ) (vl-some (function (lambda ( z ) (or (and (equal (car z) (car y) 1e-6) (equal (cadr z) (cadr y) 1e-6)) (and (equal (car z) (cadr y) 1e-6) (equal (cadr z) (car y) 1e-6))))) lil))) x))) (cdr lillst)))
              (setq lils nil errlis nil fff t)
            )
            ( fff
              (setq lils (apply (function append) lillst) errlis nil)
            )
            ( t
              (setq lils (car lillst) errlis nil)
            )
          )
        )
      )
      (if (cdr lillst)
        (progn
          (setq k 0)
          (foreach lil (setq lillst (cdr (uniquelillst (reverse lillst))))
            (setq k (1+ k))
            (vla-move (vla-copy (vlax-ename->vla-object lw)) (vlax-3d-point (list 0.0 0.0 0.0)) (vlax-3d-point (list (* k dx) 0.0 0.0)))
            (foreach li (reverse lil)
              (entmake (list (cons 0 "LINE") (cons 10 (mapcar (function +) (list (* k dx) 0.0) (car li))) (cons 11 (mapcar (function +) (list (* k dx) 0.0) (cadr li))) (cons 62 (1+ k))))
            )
          )
        )
      )
      (if (null lillst)
        (prompt "\nThere are no alternate solutions that could be founded at least not with this algorithm...")
        (prompt "\nSome solution(s) was(were) founded... Note that there may be more solutions, but with some different algorithm...")
      )
      (prompt "\nElapsed time : ") (princ (rtos (- (car (_vl-times)) ti) 2 16)) (prompt " milliseconds...")
    )
  )
  (vl-cmdf "_.UNDO" "_E")
  (*error* nil)
)