;;;---------------------------------------------------------------;;;
;;;                                                               ;;;
;;;                  HIP ROOF - 2D RIDGE EDGES                    ;;;
;;;                                                               ;;;
;;;  Author : Marko Ribar, d.i.a. (architect)                     ;;;
;;;  Autolisp routine for AutoCAD or BricsCAD                     ;;;
;;;  Copyright (C) 2021.                                          ;;;
;;;  Tested and programmed on Windows 10 OS                       ;;;
;;;  Bugs or failures may appear and aren't authors responsibility;;;
;;;  LSP file is free to be used for improvements...              ;;;
;;;  All relevant suggestions are welcomed...                     ;;;
;;;                                                               ;;;
;;;---------------------------------------------------------------;;;

(defun c:roof2d-new-short ( / *error* 3pline uniquelil unique unit mid clockwise-p inside-p distp2t offsett2p removesingles removedoubles correctplanedist collinear-p unioncollinearplaneprints car-sort processtxtipl chksolution test chklili findlinesbetweentl processipl processipll processplaa postprocessplaa process cmde s ti lw lwi lwx pl tl utl pla n plaa x y lil ll ip ipl ipldl ipld pla1 ipldd errlis plal ret pos errli iter dd lilo )

  (vl-load-com)

  (defun *error* ( m )
    (if cmde
      (setvar 'cmdecho cmde)
    )
    (if (and lwi (not (vlax-erased-p lwi)))
      (entdel lwi)
    )
    (if m
      (prompt m)
    )
    (princ)
  )

  (defun 3pline ( p1 p p2 )
    (equal (distance p1 p2) (+ (distance p1 p) (distance p p2)) 5e-8)
  )

  (defun uniquelil ( l )
    (if l (cons (car l) (uniquelil (vl-remove-if (function (lambda ( x ) (or (equal x (car l) 1e-6) (equal x (reverse (car l)) 1e-6)))) l))))
  )

  (defun unique ( l )
    (if l (cons (car l) (unique (vl-remove-if (function (lambda ( x ) (equal x (car l) 1e-6))) l))))
  )

  (defun unit ( v / d )
    (if (not (equal (setq d (distance (list 0.0 0.0 0.0) v)) 0.0 1e-8))
      (mapcar (function (lambda ( x ) (/ x d))) v)
    )
  )

  (defun mid ( p1 p2 )
    (mapcar (function (lambda ( a b ) (/ (+ a b) 2.0))) p1 p2)
  )

  (defun clockwise-p ( p1 p2 p3 )
    (minusp (sin (- (angle p1 p3) (angle p1 p2))))
  )

  (defun inside-p ( pt lw lwi )
    (< (distance pt (vlax-curve-getclosestpointto lwi pt)) (distance pt (vlax-curve-getclosestpointto lw pt)))
  )

  (defun distp2t ( p tt / i )
    (if (setq i (inters p (polar p (+ (angle (car tt) (cadr tt)) (* 0.5 pi)) 1.0) (car tt) (cadr tt) nil))
      (distance p i)
    )
  )

  (defun offsett2p ( p tt d / ip v v1 )
    (setq ip (inters p (polar p (+ (angle (car tt) (cadr tt)) (* 0.5 pi)) 1.0) (car tt) (cadr tt) nil))
    (setq v (mapcar (function -) p ip))
    (setq v1 (unit v))
    (list (mapcar (function +) (car tt) (mapcar (function *) v1 (list d d))) (mapcar (function +) (cadr tt) (mapcar (function *) v1 (list d d))))
  )

  (defun removesingles ( l / a )
    (while (setq a (vl-some (function (lambda ( x ) (if (= (1- (length l)) (length (vl-remove-if (function (lambda ( y ) (equal x y 1e-6))) l))) x))) l))
      (setq l (vl-remove-if (function (lambda ( x ) (equal x a 1e-6))) l))
    )
    l
  )

  (defun removedoubles ( l / a )
    (while (setq a (vl-some (function (lambda ( x ) (if (= (- (length l) 2) (length (vl-remove-if (function (lambda ( y ) (equal x y 1e-6))) l))) x))) l))
      (setq l (vl-remove-if (function (lambda ( x ) (equal x a 1e-6))) l))
    )
    l
  )

  (defun correctplanedist ( ip / d )
    (if (and (caar ip) (caadr ip) (cadadr ip) (caaddr ip) (cadr (caddr ip)) (equal (setq d (distp2t (caar ip) (cadr ip))) (distp2t (caar ip) (caddr ip)) 1e-6) d)
      d
    )
  )

  (defun collinear-p ( p1 p2 p3 )
    (
      (lambda ( a b c )
        (or
          (equal (+ a b) c 1e-10)
          (equal (+ b c) a 1e-10)
          (equal (+ c a) b 1e-10)
        )
      )
      (distance p1 p2) (distance p2 p3) (distance p1 p3)
    )
  )

  (defun unioncollinearplaneprints ( tl / a b tll )
    (while (setq a (car tl))
      (setq b (vl-remove-if-not (function (lambda ( x ) (and (collinear-p (car a) (cadr a) (car x)) (collinear-p (car a) (cadr a) (cadr x))))) tl))
      (setq tll (cons a tll))
      (if b
        (setq tl (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal x y 1e-6))) b))) tl))
        (setq tl (cdr tl))
      )
    )
    tll
  )

  (defun car-sort ( lst cmp / rtn )
    (setq rtn (car lst))
    (foreach itm (cdr lst)
      (if (apply cmp (list itm rtn))
        (setq rtn itm)
      )
    )
    rtn
  )

  (defun processtxtipl ( tl / ipl tl1 tl2 intt )
    (setq tl1 tl tl2 tl)
    (foreach t1 tl1
      (setq tl2 (cdr tl2))
      (foreach t2 tl2
        (if (setq intt (inters (car t1) (polar (car t1) (angle (car t1) (cadr t1)) 1.0) (car t2) (polar (car t2) (angle (car t2) (cadr t2)) 1.0) nil))
          (setq ipl (cons intt ipl))
          (setq ipl (cons (angle (car t1) (cadr t1)) ipl))
        )
      )
    )
    ipl
  )

  (defun chksolution ( errli / allplanesips anglst )
    (if (and (car errli) (cadr errli))
      (progn
        (setq allplanesips (processtxtipl tl))
        (setq allplanesips (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal x y 1e-6))) pl))) allplanesips))
        (setq anglst (vl-remove-if (function listp) allplanesips))
        (if (vl-some (function (lambda ( x ) (or (equal x 1e-8 1e-6) (equal x -1e-8 1e-6)))) anglst)
          (setq anglst (cons 0.0 anglst) anglst (cons pi anglst) anglst (cons (* 2 pi) anglst))
        )
        (setq allplanesips (vl-remove-if-not (function listp) allplanesips))
        (if (or
              (vl-some (function (lambda ( x ) (or
                                                 (3pline (car errli) x (cadr errli))
                                                 (3pline (car errli) (cadr errli) x)
                                                 (3pline (cadr errli) (car errli) x)
                                               )
                                 )) allplanesips
              )
              (vl-some (function (lambda ( x ) (or (equal (angle (car errli) (cadr errli)) x 1e-8) (equal (angle (cadr errli) (car errli)) x 1e-8)))) anglst)
              (vl-some (function (lambda ( x ) (collinear-p (car errli) (cadr errli) x))) pl)
            )
          t
        )
      )
      t
    )
  )

  (defun test nil
    (and
      (not (vl-some (function (lambda ( x ) (and (not (vl-some (function (lambda ( y ) (inters (car x) (cadr x) (car y) (cadr y)))) lil)) (not (vl-some (function (lambda ( y ) (3pline (car y) (polar (car x) (angle (car x) (cadr x)) 0.01) (cadr y)))) tl)) (inside-p (polar (car x) (angle (car x) (cadr x)) 0.01) lw lwi) (inside-p (polar (cadr x) (angle (cadr x) (car x)) 0.01) lw lwi)))) ll))
      (vl-every (function (lambda ( li ) (chksolution li))) lil)
      (vl-every (function (lambda ( x ) (vl-some (function (lambda ( y ) (equal x y 1e-6))) (apply (function append) lil)))) pl)
      (not (vl-some (function (lambda ( li1 ) (vl-some (function (lambda ( li2 / ip ) (and (setq ip (inters (car li1) (cadr li1) (car li2) (cadr li2))) (not (equal ip (car li1) 1e-6)) (not (equal ip (cadr li1) 1e-6)) (not (equal ip (car li2) 1e-6)) (not (equal ip (cadr li2) 1e-6))))) (vl-remove li1 lil)))) lil))
    )
  )

  (defun chklili ( lil / lilpts )
    (setq lilpts (apply (function append) lil))
    (setq lilpts (vl-remove-if-not (function (lambda ( x ) (= (length (vl-remove-if (function (lambda (y) (equal x y 1e-6))) lilpts)) (- (length lilpts) 2)))) lilpts))
    lilpts
  )

  (defun findlinesbetweentl ( tl / ll tl1 tl2 )
    (setq tl1 tl tl2 tl)
    (foreach t1 tl1
      (setq tl2 (cdr tl2))
      (foreach t2 tl2
        (setq ll (cons (list (mid (car t1) (cadr t1)) (mid (car t2) (cadr t2))) ll))
      )
    )
    ll
  )

  (defun processipl ( pla / pla1 pla2 intt xx xxx xxxx uu ipl )
    (setq pla1 pla pla2 pla)
    (foreach p1 pla1
      (setq pla2 (cdr pla2))
      (foreach p2 pla2
        (setq intt (inters (caar p1) (polar (caar p1) (cadar p1) 1.0) (caar p2) (polar (caar p2) (cadar p2) 1.0) nil))
        (if (or (equal intt (caar p1) 1e-6) (equal intt (caar p2) 1e-6))
          (setq intt nil)
        )
        (if intt
          (if (setq xxx (vl-some (function (lambda ( x ) (if (= (length (vl-remove x (append (list (cadr p1) (caddr p1)) (list (cadr p2) (caddr p2))))) 2) x))) (append (list (cadr p1) (caddr p1)) (list (cadr p2) (caddr p2)))))
            (if (or (and (caadr p1) (cadadr p1) (caaddr p1) (cadr (caddr p1)) (or (equal (angle (caadr p1) (cadadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6) (equal (angle (cadadr p1) (caadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6)) (setq xx (vl-some (function (lambda ( x ) (if (equal x (mapcar (function +) intt (mapcar (function -) intt (caar p2))) 1e-6) x))) pl)) (or (equal (angle xx intt) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6) (equal (angle intt xx) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6))) (and (caadr p2) (cadadr p2) (caaddr p2) (cadr (caddr p2)) (or (equal (angle (caadr p2) (cadadr p2)) (angle (caaddr p2) (cadr (caddr p2))) 1e-6) (equal (angle (cadadr p2) (caadr p2)) (angle (caaddr p2) (cadr (caddr p2))) 1e-6)) (setq xx (vl-some (function (lambda ( x ) (if (equal x (mapcar (function +) intt (mapcar (function -) intt (caar p1))) 1e-6) x))) pl)) (or (equal (angle xx intt) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6) (equal (angle intt xx) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6))))
              (cond
                ( (and (caadr p1) (cadadr p1) (caaddr p1) (cadr (caddr p1)) (or (equal (angle (caadr p1) (cadadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6) (equal (angle (cadadr p1) (caadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6)))
                  (setq ipl (cons (list (list intt (if (setq xx (vl-remove xxx (list (cadr p2) (caddr p2)))) (angle (caar xx) (cadar xx)) (cadar p2))) (car xx) (if (and (caar xx) (cadar xx) (distp2t intt (car xx))) (offsett2p intt (car xx) (* (distp2t intt (car xx)) 2.0))) nil p1 p2) ipl))
                )
                ( t
                  (setq ipl (cons (list (list intt (if (setq xx (vl-remove xxx (list (cadr p1) (caddr p1)))) (angle (caar xx) (cadar xx)) (cadar p1))) (car xx) (if (and (caar xx) (cadar xx) (distp2t intt (car xx))) (offsett2p intt (car xx) (* (distp2t intt (car xx)) 2.0))) nil p1 p2) ipl))
                )
              )
              (setq ipl (cons (list (list intt (if (setq xxxx (if (and (setq xx (vl-remove xxx (append (list (cadr p1) (caddr p1)) (list (cadr p2) (caddr p2))))) (= (length xx) 2)) (inters (caar xx) (cadar xx) (caadr xx) (cadadr xx) nil))) (angle xxxx intt) (angle (caar xx) (cadar xx)))) (car xx) (cadr xx) xxx p1 p2) ipl))
            )
            (cond
              ( (or (and (caadr p1) (cadadr p1) (caaddr p1) (cadr (caddr p1)) (or (equal (angle (caadr p1) (cadadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6) (equal (angle (cadadr p1) (caadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6)) (setq xx (vl-some (function (lambda ( x ) (if (equal x (mapcar (function +) intt (mapcar (function -) intt (caar p2))) 1e-6) x))) pl)) (or (equal (angle xx intt) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6) (equal (angle intt xx) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6))) (and (caadr p2) (cadadr p2) (caaddr p2) (cadr (caddr p2)) (or (equal (angle (caadr p2) (cadadr p2)) (angle (caaddr p2) (cadr (caddr p2))) 1e-6) (equal (angle (cadadr p2) (caadr p2)) (angle (caaddr p2) (cadr (caddr p2))) 1e-6)) (setq xx (vl-some (function (lambda ( x ) (if (equal x (mapcar (function +) intt (mapcar (function -) intt (caar p1))) 1e-6) x))) pl)) (or (equal (angle xx intt) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6) (equal (angle intt xx) (cadar (vl-some (function (lambda ( x ) (if (equal xx (caar x) 1e-6) x))) pla)) 1e-6))))
                (cond
                  ( (and (caadr p1) (cadadr p1) (caaddr p1) (cadr (caddr p1)) (or (equal (angle (caadr p1) (cadadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6) (equal (angle (cadadr p1) (caadr p1)) (angle (caaddr p1) (cadr (caddr p1))) 1e-6)))
                    (setq ipl (cons (list (list intt (if (setq xx (vl-remove xxx (list (cadr p2) (caddr p2)))) (angle (caar xx) (cadar xx)) (cadar p2))) (car xx) (if (and (caar xx) (cadar xx) (distp2t intt (car xx))) (offsett2p intt (car xx) (* (distp2t intt (car xx)) 2.0))) nil p1 p2) ipl))
                  )
                  ( t
                    (setq ipl (cons (list (list intt (if (setq xx (vl-remove xxx (list (cadr p1) (caddr p1)))) (angle (caar xx) (cadar xx)) (cadar p1))) (car xx) (if (and (caar xx) (cadar xx) (distp2t intt (car xx))) (offsett2p intt (car xx) (* (distp2t intt (car xx)) 2.0))) nil p1 p2) ipl))
                  )
                )
              )
              ( (= (length (setq uu (unioncollinearplaneprints (append (list (cadr p1) (caddr p1)) (list (cadr p2) (caddr p2)))))) 3)
                (foreach pp uu
                  (if (= (length (vl-remove-if-not (function (lambda ( x ) (or (equal pp x) (and (3pline (if (> (distance (car pp) (car x)) (distance (cadr pp) (car x))) (car pp) (cadr pp)) (if (> (distance (car pp) (car x)) (distance (cadr pp) (car x))) (cadr pp) (car pp)) (car x)) (3pline (if (> (distance (car pp) (cadr x)) (distance (cadr pp) (cadr x))) (car pp) (cadr pp)) (if (> (distance (car pp) (cadr x)) (distance (cadr pp) (cadr x))) (cadr pp) (car pp)) (cadr x)))))) (append (list (cadr p1) (caddr p1)) (list (cadr p2) (caddr p2))))) 2)
                    (setq xxx pp)
                  )
                )
                (setq ipl (cons (list (list intt (if (setq xxxx (if (and (setq xx (vl-remove xxx uu)) (= (length xx) 2)) (inters (caar xx) (cadar xx) (caadr xx) (cadadr xx) nil))) (angle xxxx intt) (angle (caar xx) (cadar xx)))) (car xx) (cadr xx) nil p1 p2) ipl))
              )
            )
          )
        )
      )
    )
    (setq ipl (vl-remove-if-not (function (lambda ( p / d1 d2 ) (and (inside-p (caar p) lw lwi) (removedoubles (removesingles (vl-remove nil (mapcar (function (lambda ( tt ) (distp2t (caar p) tt))) utl)))) (if (and (caadr p) (cadadr p) (caaddr p) (cadr (caddr p))) (or (and (setq d1 (distance (caar p) (vlax-curve-getclosestpointto lw (caar p)))) (setq d2 (correctplanedist p)) (> d1 d2)) (and d1 d2 (equal d1 d2 1e-6))) t)))) ipl))
  )

  (defun processipll ( / ip ipl1 ipl1l ipll )
    (foreach pla1 pla
      (setq ipl1l (vl-remove-if-not (function (lambda ( z ) (or (equal (angle (caar z) (caar pla1)) (cadar pla1) 1e-6) (equal (angle (caar pla1) (caar z)) (cadar pla1) 1e-6)))) ipl))
      (setq ipl1 (car-sort ipl1l (function (lambda ( a b ) (if (equal (distance (caar a) (caar pla1)) (distance (caar b) (caar pla1)) 1e-6) (< (distance (caar a) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr a))))) (distance (caar b) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr b)))))) (if (equal (distance (caar a) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr a))))) (distance (caar b) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr b))))) 1e-6) (< (distance (caar a) (caar pla1)) (distance (caar b) (caar pla1))) (< (distance (caar a) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr a))))) (distance (caar b) (caar (car (vl-remove-if (function (lambda ( x ) (equal (caar pla1) (caar x) 1e-6))) (cddddr b))))))))))))
      (setq ipl1 (car-sort ipl1l (function (lambda ( a b ) (< (distance (caar a) (caar pla1)) (distance (caar b) (caar pla1)))))))
      (setq ip nil)
      (if ipl1
        (vl-some (function (lambda ( x ) (or (setq ip (inters (polar (car x) (angle (car x) (cadr x)) 1e-3) (polar (cadr x) (angle (cadr x) (car x)) 1e-3) (caaar (cddddr ipl1)) (caar ipl1))) (setq ip (inters (polar (car x) (angle (car x) (cadr x)) 1e-3) (polar (cadr x) (angle (cadr x) (car x)) 1e-3) (caaadr (cddddr ipl1)) (caar ipl1)))))) tl)
      )
      (if (and ipl1 (not ip) (if (and (setq zzz (vl-some (function (lambda ( x ) (vl-some (function (lambda ( y ) (if (and (not (equal (caar x) (caar y) 1e-6)) (not (equal (caar x) (caar ipl1) 1e-6)) (not (equal (caar y) (caar ipl1) 1e-6)) (or (and (not (equal (caar y) (caaar (cddddr ipl1)) 1e-6)) (not (equal (caar x) (caaar (cddddr ipl1)) 1e-6)) (and (inters (polar (caar y) (cadar y) 1e+6) (polar (caar y) (cadar y) -1e+6) (caaar (cddddr ipl1)) (caar ipl1)) (equal (caar x) (inters (caar y) (polar (caar y) (cadar y) 1.0) (caaar (cddddr ipl1)) (caar ipl1) nil) 1e-6))) (and (not (equal (caar y) (caaadr (cddddr ipl1)) 1e-6)) (not (equal (caar x) (caaadr (cddddr ipl1)) 1e-6)) (and (inters (polar (caar y) (cadar y) 1e+6) (polar (caar y) (cadar y) -1e+6) (caaadr (cddddr ipl1)) (caar ipl1)) (equal (caar x) (inters (caar y) (polar (caar y) (cadar y) 1.0) (caaadr (cddddr ipl1)) (caar ipl1) nil) 1e-6))))) (list x y)))) (append pla ipl)))) (append pla ipl))) (vl-some (function (lambda ( x ) (and (not (equal (caar x) (caaar zzz) 1e-6)) (not (equal (caar x) (caaadr zzz) 1e-6)) (3pline (caaar zzz) (caar x) (caaadr zzz))))) (append pla ipl))) t (not zzz)))
        (setq ipll (cons (vl-sort (vl-remove-if-not (function (lambda ( x ) (equal (caar ipl1) (caar x) 1e-6))) ipl) (function (lambda ( a b ) (< (max (distance (caar a) (caaar (cddddr a))) (distance (caar a) (caaadr (cddddr a)))) (max (distance (caar b) (caaar (cddddr b))) (distance (caar b) (caaadr (cddddr b)))))))) ipll))
      )
    )
    (if (vl-some (function (lambda ( x ) (equal (caar x) (cadar lil) 1e-6))) pla)
      (car-sort ipll (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b))) (equal c d 1e-6)) (< (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (if (or (null c) (null d)) (< (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (< c d))))))
      (if lil
        (car-sort ipll (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b))) (equal c d 1e-6)) (> (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (if (or (null c) (null d)) (> (distance (cadar lil) (caaar a)) (distance (cadar lil) (caaar b))) (< c d))))))
        (car-sort ipll (function (lambda ( a b / c d ) (if (and (setq c (correctplanedist (car a))) (setq d (correctplanedist (car b)))) (< c d) (< (distance (caaar a) (vlax-curve-getclosestpointto lw (caaar a))) (distance (caaar b) (vlax-curve-getclosestpointto lw (caaar b))))))))
      )
    )
  )

  (defun processplaa ( pla / errlis dd pos errli ip iter ip1 ip2 )
    (setq ipl (processipl (vl-remove nil pla)))
    (if (setq errlis (vl-remove-if-not (function (lambda ( x ) (vl-some (function (lambda ( y ) (or (and (setq ip1 (inters (caar y) (caaar (cddddr y)) (car x) (cadr x))) (not (equal (caar y) ip1 1e-6)) (not (equal (caaar (cddddr y)) ip1 1e-6)) (not (equal (car x) ip1 1e-6)) (not (equal (cadr x) ip1 1e-6))) (and (setq ip2 (inters (caar y) (caaadr (cddddr y)) (car x) (cadr x))) (not (equal (caar y) ip2 1e-6)) (not (equal (caaadr (cddddr y)) ip2 1e-6)) (not (equal (car x) ip2 1e-6)) (not (equal (cadr x) ip2 1e-6)))))) ipl))) lil))
      (if (setq dd (vl-remove-if-not (function (lambda ( x ) (vl-some (function (lambda ( y ) (or (if (setq ip (inters (caar x) (caaar (cddddr x)) (car y) (cadr y))) (< (distance (caar x) (caaar (cddddr x))) (distance (caaar (cddddr x)) ip))) (if (setq ip (inters (caar x) (caaadr (cddddr x)) (car y) (cadr y))) (< (distance (caar x) (caaadr (cddddr x))) (distance (caaadr (cddddr x)) ip)))))) errlis))) ipl))
        (setq ipl dd)
        (if (setq dd (vl-remove-if (function (lambda ( x ) (vl-some (function (lambda ( y ) (or (inters (caar x) (caaar (cddddr x)) (car y) (cadr y)) (inters (caar x) (caaadr (cddddr x)) (car y) (cadr y))))) errlis))) ipl))
          (setq ipl dd)
          (progn
            (setq pos (car-sort (mapcar (function (lambda ( x ) (vl-position x (reverse lil)))) errlis) (function <)))
            (setq errli (nth pos (reverse lil)))
            (setq ip (vl-some (function (lambda ( x ) (or (and (setq ip1 (inters (caar x) (caaar (cddddr x)) (car errli) (cadr errli))) (not (equal (caar x) (car errli) 1e-6)) (not (equal (caar x) (cadr errli) 1e-6)) (not (equal (caaar (cddddr x)) (car errli) 1e-6)) (not (equal (caaar (cddddr x)) (cadr errli) 1e-6))) (and (setq ip2 (inters (caar x) (caaadr (cddddr x)) (car errli) (cadr errli))) (not (equal (caar x) (car errli) 1e-6)) (not (equal (caar x) (cadr errli) 1e-6)) (not (equal (caaadr (cddddr x)) (car errli) 1e-6)) (not (equal (caaadr (cddddr x)) (cadr errli) 1e-6)))) (cond (ip1 ip1) (ip2 ip2)))) ipl))
            (setq iter (fix (/ pos 2.0)))
            (setq lil (cdr (member (nth (* 2 iter) (reverse lil)) lil)))
            (setq ipl (processipl (setq pla (vl-remove nil (nth iter (reverse plal))))))
            (setq plal (cdr (member (nth iter (reverse plal)) plal)))
            (if (setq dd (vl-remove-if-not (function (lambda ( x ) (or (< (distance (caar x) (caaar (cddddr x))) (distance (caaar (cddddr x)) ip)) (< (distance (caar x) (caaadr (cddddr x))) (distance (caaadr (cddddr x)) ip))))) ipl))
              (setq ipl dd)
              (if (setq dd (vl-remove-if (function (lambda ( x ) (or (3pline (caar x) ip (caaar (cddddr x))) (3pline (caar x) ip (caaadr (cddddr x)))))) ipl))
                (setq ipl dd)
              )
            )
          )
        )
      )
    )
    (list (processipll) pla)
  )

  (defun postprocessplaa nil
    (setq plal (cons (if (null plal) pla (cadr ret)) plal))
    (if plaa
      (foreach pla1 (reverse plaa)
        (if (not (vl-some (function (lambda ( x ) (equal pla1 x 1e-6))) pla))
          (setq pla (cons pla1 pla))
        )
      )
      (progn
        (setq n (length utl))
        (if (and (test) (not (chklili lil)) (<= n (length lil)))
          (setq n 0)
          (progn
            (foreach pla1 pla
              (if (setq ip (vl-some (function (lambda ( x ) (if (or (equal (angle (caar pla1) x) (cadar pla1) 1e-6) (equal (angle x (caar pla1)) (cadar pla1) 1e-6)) x))) (mapcar (function cadr) lil)))
                (if (and (not (vl-some (function (lambda ( z ) (equal z (list (caar pla1) ip) 1e-6))) lil)) (not (vl-some (function (lambda ( z ) (equal z (list ip (caar pla1)) 1e-6))) lil)))
                  (setq lil (cons (list (caar pla1) ip) lil))
                )
              )
            )
            (setq n 0)
          )
        )
      )
    )
    (if plaa
      (if (= (length plaa) 1)
        (progn
          (setq x (caaar (cddddr (car plaa))))
          (setq y (caaadr (cddddr (car plaa))))
          (if (and x y (caaar plaa) (not (or (vl-some (function (lambda ( z ) (equal z (list x (caaar plaa)) 1e-6))) lil) (vl-some (function (lambda ( z ) (equal z (list (caaar plaa) x) 1e-6))) lil))))
            (if (not (equal x (caaar plaa) 1e-6))
              (progn
                (setq lil (cons (list x (caaar plaa)) lil))
                (setq pla (vl-remove-if (function (lambda ( z ) (equal x (caar z) 1e-6))) pla))
              )
            )
          )
          (if (and x y (caaar plaa) (not (or (vl-some (function (lambda ( z ) (equal z (list y (caaar plaa)) 1e-6))) lil) (vl-some (function (lambda ( z ) (equal z (list (caaar plaa) y) 1e-6))) lil))))
            (if (not (equal y (caaar plaa) 1e-6))
              (progn
                (setq lil (cons (list y (caaar plaa)) lil))
                (setq pla (vl-remove-if (function (lambda ( z ) (equal y (caar z) 1e-6))) pla))
              )
            )
          )
        )
        (foreach pla1 plaa
          (setq x (caaar (cddddr pla1)))
          (setq y (caaadr (cddddr pla1)))
          (if (and x y (caar pla1) (not (or (vl-some (function (lambda ( z ) (equal z (list x (caar pla1)) 1e-6))) lil) (vl-some (function (lambda ( z ) (equal z (list (caar pla1) x) 1e-6))) lil))))
            (if (not (equal x (caar pla1) 1e-6))
              (progn
                (setq lil (cons (list x (caar pla1)) lil))
                (setq pla (vl-remove-if (function (lambda ( z ) (equal x (caar z) 1e-6))) pla))
                (if (< 2 (length (unioncollinearplaneprints (unique (apply (function append) (mapcar (function (lambda ( x ) (list (list (caar x) (caaar (cddddr x))) (list (caar x) (caaadr (cddddr x)))))) plaa))))))
                  (setq pla (vl-remove-if (function (lambda ( z ) (equal (caar pla1) (caar z) 1e-6))) pla))
                )
              )
            )
          )
          (if (and x y (caar pla1) (not (or (vl-some (function (lambda ( z ) (equal z (list y (caar pla1)) 1e-6))) lil) (vl-some (function (lambda ( z ) (equal z (list (caar pla1) y) 1e-6))) lil))))
            (if (not (equal y (caar pla1) 1e-6))
              (progn
                (setq lil (cons (list y (caar pla1)) lil))
                (setq pla (vl-remove-if (function (lambda ( z ) (equal y (caar z) 1e-6))) pla))
                (if (< 2 (length (unioncollinearplaneprints (unique (apply (function append) (mapcar (function (lambda ( x ) (list (list (caar x) (caaar (cddddr x))) (list (caar x) (caaadr (cddddr x)))))) plaa))))))
                  (setq pla (vl-remove-if (function (lambda ( z ) (equal (caar pla1) (caar z) 1e-6))) pla))
                )
              )
            )
          )
        )
      )
    )
  )

  (defun process ( processplafun )
    (while (> n 0)
      (if (null plaa)
        (progn
          (setq ipl (processipl pla))
          (setq ipldl (mapcar (function (lambda ( x ) (list (correctplanedist x) x))) ipl))
          (setq pla1 (cadr (car-sort (vl-remove-if (function (lambda ( x ) (null (car x)))) ipldl) (function (lambda ( a b ) (if (equal (car a) (car b) 1e-6) (< (length (vl-remove-if-not (function (lambda ( x ) (equal (caaadr a) (caaadr x) 1e-6))) (vl-remove-if (function (lambda ( x ) (null (car x)))) ipldl))) (length (vl-remove-if-not (function (lambda ( x ) (equal (caaadr b) (caaadr x) 1e-6))) (vl-remove-if (function (lambda ( x ) (null (car x)))) ipldl)))) (< (car a) (car b))))))))
          (setq plaa (mapcar (function cadr) (vl-remove-if-not (function (lambda ( x ) (equal (caar pla1) (caaadr x) 1e-6))) (vl-remove-if (function (lambda ( x ) (null (car x)))) ipldl))))
          (setq plaa (list (car (vl-remove-if (function (lambda ( x ) (null (cadddr x)))) plaa))))
        )
        (if (equal plaa (setq plaa (unique (car (setq ret (apply processplafun (list (unique pla))))))) 1e-6)
          (setq n 0)
        )
      )
      (postprocessplaa)
    )
  )

  (setq cmde (getvar 'cmdecho))
  (setvar 'cmdecho 0)
  (vl-cmdf "_.UNDO" "_BE")
  (prompt "\nPick a closed polygonal LWPOLYLINE...")
  (if (setq s (ssget "_+.:E:S" '((0 . "LWPOLYLINE") (-4 . "&=") (70 . 1) (-4 . "<not") (-4 . "<>") (42 . 0.0) (-4 . "not>"))))
    (progn
      (setq ti (car (_vl-times)))
      (if (= 0 (getvar 'worlducs))
        (vl-cmdf "_.UCS" "_W")
      )
      (setq lwx (entget (setq lw (ssname s 0))))
      (setq lwi (vlax-vla-object->ename (car (vlax-invoke (vlax-ename->vla-object lw) 'offset 0.001))))
      (if (< (vlax-curve-getarea lw) (vlax-curve-getarea lwi))
        (progn
          (entdel lwi)
          (setq lwi (vlax-vla-object->ename (car (vlax-invoke (vlax-ename->vla-object lw) 'offset -0.001))))
        )
      )
      (setq pl (mapcar (function (lambda ( p ) (mapcar (function +) (list 0 0) (trans p lw 0)))) (mapcar (function cdr) (vl-remove-if (function (lambda ( x ) (/= (car x) 10))) lwx))))
      (setq pl (append pl (list (car pl))))
      (setq tl (mapcar (function (lambda ( a b ) (list a b))) (reverse (cdr (reverse pl))) (cdr pl)))
      (setq pla (mapcar (function (lambda ( p mp ) (list p (angle p mp)))) pl (mapcar (function (lambda ( a b ) (cond ( (3pline (car a) (car b) (cadr b)) (vlax-curve-getclosestpointto lwi (car b)) ) ( t (if (clockwise-p (car a) (car b) (cadr b)) (mid (polar (cadr a) (angle (cadr a) (car a)) -1.0) (polar (car b) (angle (car b) (cadr b)) -1.0)) (mid (polar (cadr a) (angle (cadr a) (car a)) 1.0) (polar (car b) (angle (car b) (cadr b)) 1.0))) )))) (cons (last tl) tl) tl)))
      (setq pla (mapcar (function (lambda ( a pla b ) (list pla a b))) (cons (last tl) tl) pla tl))
      (setq ll (findlinesbetweentl tl))
      (setq n (length (setq utl (unioncollinearplaneprints tl))))
      (process (function processplaa))
      (if (and (caaar pla) (caaadr pla) (not (equal (caaar pla) (caaadr pla) 1e-6)) (chksolution (list (caaar pla) (caaadr pla))))
        (setq lil (cons (list (caaadr pla) (caaar pla)) lil))
        (if (and (caaar pla) (caaadr pla) (not (equal (caaar pla) (caaadr pla) 1e-6)))
          (progn
            (setq x (car-sort (vl-remove-if-not (function (lambda ( x ) (or (equal (angle (caaar pla) x) (cadaar pla) 1e-6) (equal (angle x (caaar pla)) (cadaar pla) 1e-6)))) (apply (function append) lil)) (function (lambda ( a b ) (< (distance (caaar pla) a) (distance (caaar pla) b))))))
            (if (and x (chksolution (list x (caaar pla))) (not (vl-some (function (lambda ( z ) (or (equal z (list x (caaar pla)) 1e-6) (equal z (list (caaar pla) x) 1e-6)))) lil)))
              (setq lil (cons (list x (caaar pla)) lil))
            )
            (setq y (car-sort (vl-remove-if-not (function (lambda ( x ) (or (equal (angle (caaadr pla) x) (cadar (cadr pla)) 1e-6) (equal (angle x (caaadr pla)) (cadar (cadr pla)) 1e-6)))) (apply (function append) lil)) (function (lambda ( a b ) (< (distance (caaadr pla) a) (distance (caaadr pla) b))))))
            (if (and y (chksolution (list y (caaadr pla))) (not (vl-some (function (lambda ( z ) (or (equal z (list y (caaadr pla)) 1e-6) (equal z (list (caaadr pla) y) 1e-6)))) lil)))
              (setq lil (cons (list y (caaadr pla)) lil))
            )
          )
        )
      )
      (setq n (length utl))
      (if (and (test) (not (chklili lil)) (<= n (length lil)))
        (foreach li (reverse lil)
          (entmake (list '(0 . "LINE") (cons 10 (car li)) (cons 11 (cadr li)) (cons 62 3)))
        )
        (while (not (equal lil lilo 1e-6))
          (setq lilo lil)
          (if (and (setq lil (uniquelil lil)) (setq errlis (vl-remove-if-not (function (lambda ( x ) (vl-some (function (lambda ( y ) (and (setq ip (inters (car x) (cadr x) (car y) (cadr y))) (not (equal (car x) ip 1e-6)) (not (equal (cadr x) ip 1e-6)) (not (equal (car y) ip 1e-6)) (not (equal (cadr y) ip 1e-6))))) (vl-remove-if (function (lambda ( z ) (equal z x 1e-6))) lil)))) lil)))
            (progn
              (setq pos (car-sort (mapcar (function (lambda ( x ) (vl-position x (reverse lil)))) errlis) (function <)))
              (setq errli (nth pos (reverse lil)))
              (setq ip (car-sort (vl-remove nil (mapcar (function (lambda ( x ) (if (and (setq ip (inters (car errli) (cadr errli) (car x) (cadr x))) (not (equal (car errli) ip 1e-6)) (not (equal (cadr errli) ip 1e-6)) (not (equal (car x) ip 1e-6)) (not (equal (cadr x) ip 1e-6))) ip))) lil)) (function (lambda ( a b ) (< (distance (car errli) a) (distance (car errli) b))))))
              (setq iter (fix (/ pos 2.0)))
              (setq lil (cdr (member (nth (* 2 iter) (reverse lil)) lil)))
              (setq ipl (processipl (setq pla (vl-remove nil (nth iter (reverse plal))))))
              (setq plal (cdr (member (nth iter (reverse plal)) plal)))
              (if (setq dd (vl-remove-if-not (function (lambda ( x ) (or (< (distance (caar x) (caaar (cddddr x))) (distance (caaar (cddddr x)) ip)) (< (distance (caar x) (caaadr (cddddr x))) (distance (caaadr (cddddr x)) ip))))) ipl))
                (setq ipl dd)
                (if (setq dd (vl-remove-if (function (lambda ( x ) (or (3pline (caar x) ip (caaar (cddddr x))) (3pline (caar x) ip (caaadr (cddddr x)))))) ipl))
                  (setq ipl dd)
                )
              )
              (setq plaa (unique (processipll)))
              (postprocessplaa)
              (process (function processplaa))
              (if (and (caaar pla) (caaadr pla) (not (equal (caaar pla) (caaadr pla) 1e-6)) (chksolution (list (caaar pla) (caaadr pla))))
                (setq lil (cons (list (caaadr pla) (caaar pla)) lil))
                (if (and (caaar pla) (caaadr pla) (not (equal (caaar pla) (caaadr pla) 1e-6)))
                  (progn
                    (setq x (car-sort (vl-remove-if-not (function (lambda ( x ) (or (equal (angle (caaar pla) x) (cadaar pla) 1e-6) (equal (angle x (caaar pla)) (cadaar pla) 1e-6)))) (apply (function append) lil)) (function (lambda ( a b ) (< (distance (caaar pla) a) (distance (caaar pla) b))))))
                    (if (and x (chksolution (list x (caaar pla))) (not (vl-some (function (lambda ( z ) (or (equal z (list x (caaar pla)) 1e-6) (equal z (list (caaar pla) x) 1e-6)))) lil)))
                      (setq lil (cons (list x (caaar pla)) lil))
                    )
                    (setq y (car-sort (vl-remove-if-not (function (lambda ( x ) (or (equal (angle (caaadr pla) x) (cadar (cadr pla)) 1e-6) (equal (angle x (caaadr pla)) (cadar (cadr pla)) 1e-6)))) (apply (function append) lil)) (function (lambda ( a b ) (< (distance (caaadr pla) a) (distance (caaadr pla) b))))))
                    (if (and y (chksolution (list y (caaadr pla))) (not (vl-some (function (lambda ( z ) (or (equal z (list y (caaadr pla)) 1e-6) (equal z (list (caaadr pla) y) 1e-6)))) lil)))
                      (setq lil (cons (list y (caaadr pla)) lil))
                    )
                  )
                )
              )
              (setq n (length utl))
              (if (and (test) (not (chklili lil)) (<= n (length lil)))
                (progn
                  (foreach li (reverse lil)
                    (entmake (list '(0 . "LINE") (cons 10 (car li)) (cons 11 (cadr li)) (cons 62 3)))
                  )
                  (setq lilo lil)
                )
                (if (equal lil lilo 1e-6)
                  (progn
                    (prompt "\nNO SOLUTION FOUND...")
                    (foreach li (reverse lil)
                      (entmake (list (cons 0 "LINE") (cons 10 (car li)) (cons 11 (cadr li)) (cons 62 1)))
                    )
                  )
                )
              )
            )
            (progn
              (prompt "\nNO SOLUTION FOUND...")
              (foreach li (reverse lil)
                (entmake (list (cons 0 "LINE") (cons 10 (car li)) (cons 11 (cadr li)) (cons 62 1)))
              )
              (setq lilo lil)
            )
          )
        )
      )
      (prompt "\nElapsed time : ") (princ (rtos (- (car (_vl-times)) ti) 2 16)) (prompt " milliseconds...")
    )
  )
  (vl-cmdf "_.UNDO" "_E")
  (*error* nil)
)